# -*- coding: utf-8 -*-
#COPYRIGHT 2018 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
from arcpy.arcobjects._base import _ObjectWithoutInitCall, passthrough_attr
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
from arcpy.geoprocessing._base import gp_fixargs
from arcpy.pdfdocument import PDFDocument, PDFDocumentOpen, PDFDocumentCreate
from arcpy.utils import ArgAdaptor
from arcpy._symbology import Symbology, ColorRamp, ClassBreak, RasterClassBreak, Symbol, Item, RasterItem, ItemGroup
from arcpy._renderer import UniqueValueRenderer, SimpleRenderer, Graduated_colors_renderer, Graduated_symbols_renderer
from arcpy import metadata
class constants(ArgAdaptor):
    """Represents the constants that can be passed into various ExportTo* mp functions"""
    __args__ = {
        # For add position
        'add_position': {
            'AUTO_ARRANGE': 'auto_arrange',
            'BOTTOM': 'bottom',
            'TOP': 'top'
        },
        # For color mode
        'color_mode': {
            '24-BIT_TRUE_COLOR': 1,
            '8-BIT_ADAPTIVE_PALETTE': 2,
            '8-BIT_GRAYSCALE': 3,
            '32-BIT_WITH_ALPHA': 4,
            '32-BIT_CMYK_TRUE_COLOR': 5,
            '40-BIT_CMYK_WITH_ALPHA': 6
        },
        # For element type
        'element_type': {
            'GRAPHIC_ELEMENT': 'GRAPHIC_ELEMENT',
            'LEGEND_ELEMENT': 'LEGEND_ELEMENT',
            'MAPFRAME_ELEMENT': 'MAPFRAME_ELEMENT',
            'MAPSURROUND_ELEMENT': 'MAPSURROUND_ELEMENT',
            'PICTURE_ELEMENT': 'PICTURE_ELEMENT',
            'TEXT_ELEMENT': 'TEXT_ELEMENT'
        },
        # For encryption
        'encryption': {
            'RC4': 2
        },
        # For extrusion type
        'extrusion_type': {
            'ABSOLUTE_HEIGHT': 'ABSOLUTE_HEIGHT',
            'BASE_HEIGHT': 'BASE_HEIGHT',
            'MAX_HEIGHT': 'MAX_HEIGHT',
            'MIN_HEIGHT': 'MIN_HEIGHT',
            'NONE': 'NONE'
        },
        # For image compression
        'image_compression': {
            'NONE': 1,
            'RLE': 2,
            'LZW': 3,
            'DEFLATE': 4,
            'JPEG': 5,
            'ADAPTIVE': 6
        },
        # For image quality
        'image_quality': {
            'BEST': 1,
            'BETTER': 2,
            'NORMAL': 3,
            'FASTER': 4,
            'FASTEST': 5
        },
        # For insert position
        'insert_position': {
            'AFTER': 'after',
            'BEFORE': 'before'
        },
        # For jpeg color mode
        'jpeg_color_mode': {
            '24-BIT_TRUE_COLOR': 1,
            '8-BIT_GRAYSCALE': 3
        },
        # For layer property
        'layer_property': {
            'BRIGHTNESS': 'brightness',
            'CONNECTIONPROPERTIES': 'connectionProperties',
            'CONTRAST': 'contrast',
            'DATASOURCE': 'dataSource',
            'DEFINITIONQUERY': 'definitionQuery',
            'LONGNAME': 'longName',
            'MAXTHRESHOLD': 'maxThreshold',
            'MINTHRESHOLD': 'minThreshold',
            'NAME': 'name',
            'TRANSPARENCY': 'transparency'
        },
        # For layers attributes
        'layers_attributes': {
            'NONE': 1,
            'LAYERS_ONLY': 2,
            'LAYERS_AND_ATTRIBUTES': 3
        },
        # For method
        'method': {
            'DIFFERENCE': 'DIFFERENCE',
            'INTERSECT': 'INTERSECT',
            'NEW': 'NEW',
            'SYMDIFFERENCE': 'SYMDIFFERENCE',
            'UNION': 'UNION'
        },
        # For pdf layout
        'pdf_layout': {
            'DONT_CARE': 0,
            'SINGLE_PAGE': 1,
            'ONE_COLUMN': 2,
            'TWO_COLUMN_LEFT': 3,
            'TWO_COLUMN_RIGHT': 4,
            'TWO_PAGE_LEFT': 5,
            'TWO_PAGE_RIGHT': 6
        },
        # For pdf open view
        'pdf_open_view': {
            'VIEWER_DEFAULT': 0,
            'USE_NONE': 1,
            'USE_THUMBS': 2,
            'USE_BOOKMARKS': 3,
            'FULL_SCREEN': 4,
            'LAYERS': 5,
            'ATTACHMENT': 6
        },
        # For permissions
        'permissions': {
            'ALL': -268435457,
            'OPEN': 1,
            'SECURE': 2,
            'PRINT': 4,
            'EDIT': 8,
            'COPY': 16,
            'EDIT_NOTES': 32,
            'FILL_AND_SIGN': 256,
            'DOC_ASSEMBLY': 1024,
            'HIGH_PRINT': 2052,
            'ALL_MASTER': 2104
        },
        # For server type
        'server_type': {
            'HOSTING_SERVER': 'HOSTING_SERVER'
        },
        # For service type
        'service_type': {
            'FEATURE_ACCESS': 'FEATURE_ACCESS',
            'TILED': 'TILED'
        },
        # For tiff compression
        'tiff_compression': {
            'NONE': 1,
            'JPEG': 2,
            'PACK_BITS': 3,
            'LZW': 4,
            'DEFLATE': 5
        },
        'page_range_type': {
            'ALL': 'ALL',
            'CURRENT': 'CURRENT',
            'RANGE': 'RANGE',
            'SELECTED': 'SELECTED'
        },
        'report_page_range_type': {
            'ALL': 'ALL',
            'LAST': 'LAST',
            'EVEN': 'EVEN',
            'ODD': 'ODD',
            'RANGE': 'RANGE',
        },
        'multiple_files': {
            'PDF_SINGLE_FILE': 'PDF_SINGLE_FILE',
            'PDF_MULTIPLE_FILES_PAGE_NAME': 'PDF_MULTIPLE_FILES_PAGE_NAME',
            'PDF_MULTIPLE_FILES_PAGE_NUMBER': 'PDF_MULTIPLE_FILES_PAGE_NUMBER'
        },
        # For CIM version
        'cim_version': {
            'V2': '2',
            'V3': '3'
        },

        # For time_inclusion
        'time_inclusion': {
            'INCLUDE_START_AND_END': 'INCLUDE_START_AND_END',
            'INCLUDE_ONLY_START': 'INCLUDE_ONLY_START',
            'INCLUDE_ONLY_END': 'INCLUDE_ONLY_END',
            'EXCLUDE_START_AND_END': 'EXCLUDE_START_AND_END'
        },

        # For view type
        'view_type': {
            'MAPS_AND_LAYOUTS': 'MAPS_AND_LAYOUTS',
            'MAPS': 'MAPS',
            'LAYOUTS': 'LAYOUTS',
            'REPORTS': 'REPORTS'
        },
        # For map type
        'map_type': {
            'MAP': 'MAP',
            'SCENE': 'SCENE',
            'GLOBE': 'GLOBE'
        },
        # For web service type
        'web_service_type': {
            'AUTOMATIC': 'AUTOMATIC',
            'ARCGIS_SERVER_WEB': 'ARCGIS_SERVER_WEB',
            'KML': 'KML',
            'WMS': 'WMS',
            'VECTOR_TILE': 'VECTOR_TILE'
        },
        # For page_units
        'page_units': {
            'INCH': 'INCH',
            'POINT': 'POINT',
            'CENTIMETER': 'CENTIMETER',
            'MILLIMETER': 'MILLIMETER',
        }
        }
class ArcGISProject(_ObjectWithoutInitCall):
    """ArcGISProject(aprx_path)

    Provides a reference to an ArcGIS project (.aprx) stored on disk or to the project
    currently loaded within the ArcGIS Pro application using the CURRENT keyword.

    aprx_path(String):
    A string that includes the full system path and file name of an existing
    ArcGIS project ( .aprx ) or a string that contains the CURRENT keyword."""

    dateSaved = passthrough_attr('dateSaved')
    defaultGeodatabase = passthrough_attr('defaultGeodatabase')
    defaultToolbox = passthrough_attr('defaultToolbox')
    filePath = passthrough_attr('filePath')
    activeMap = passthrough_attr('activeMap')
    homeFolder = passthrough_attr('homeFolder')
    documentVersion = passthrough_attr('version')
    activeView = passthrough_attr('activeView')
    metadata = passthrough_attr('metadata')
    isReadOnly = passthrough_attr('isReadOnly')
    folderConnections = passthrough_attr('folderConnections')

    def importDocument(self, document_path, include_layout=True, reuse_existing_maps = False):
        """ArcGISProject.importDocument(document_path, {include_layout},
        {reuse_existing_maps})


        Imports map (.mxd), globe (.3dd), and scene (.sxd) documents into an
        ArcGIS Pro project.  It can also be used to import the contents of  map
        files (.mapx), layout files (.pagx), and report files (.rptx).


        document_path(String):
        A string that includes the system path and name of a document (.mxd,
        .3dd, or .sxd) or a map file (.mapx), layout file ( .pagx), or report
        file (.rptx).


        include_layout{Boolean}:
        A Boolean parameter indicating whether the layout from a map document
        (.mxd) is imported.  If  set to True, the layout and all data frames are
        imported. If set to False, only the data frames are imported.  This
        parameter is ignored for other file types. The default value is True.


        reuse_existing_maps{Boolean}:
        A Boolean parameter to prevent the creation of duplicate maps in the
        project. If reuse_existing_maps is set to True, it checks the project
        for the maps referenced in the imported file and only copies maps that
        don't already exist in the project.  There may be cases in which maps
        have the same name in different imported sources, so you may want to set
        this value to  False. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.importDocument(*gp_fixargs((document_path, include_layout, reuse_existing_maps), True)))

    def listBrokenDataSources(self):
        """ArcGISProject.listBrokenDataSources()


        Returns a Python list of Layer and/or Table objects that have broken
        connections to their original source data for all maps in a project.
        """
        return convertArcObjectToPythonObject(self._arc_object.listBrokenDataSources(*gp_fixargs((), True)))

    def listLayouts(self, wildcard=None):
        """ArcGISProject.listLayouts({wildcard})


        Returns a Python list of Layout objects in an ArcGIS project (.aprx).


        wildcard{String}:
        A wildcard is based on the layout name and is not case sensitive.  A
        combination of asterisks (*) and characters can be used to help
        limit the resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listLayouts(*gp_fixargs((wildcard,), True)))

    def listReports(self, wildcard=None):
        """ArcGISProject.listReports({wildcard})


        Returns a Python list of Report objects in an ArcGIS project (.aprx).


        wildcard{String}:
        A wildcard is based on the report name and is not case sensitive.  A
        combination of asterisks (*) and characters can be used to help
        limit the resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listReports(*gp_fixargs((wildcard,), True)))

    def listMaps(self, wildcard=None):
        """ArcGISProject.listMaps({wildcard})


        Returns a Python list of Map objects in an ArcGIS project (.aprx).


        wildcard{String}:
        A wildcard is based on the map name and is not case sensitive. A
        combination of asterisks (*) and characters can be used to help
        limit the resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listMaps(*gp_fixargs((wildcard,), True)))

    def save(self):
        """ArcGISProject.save()


        Saves changes to an ArcGISProject  (.aprx).
        """
        return convertArcObjectToPythonObject(self._arc_object.save(*gp_fixargs((), True)))

    def saveACopy(self, file_name):
        """ArcGISProject.saveACopy(file_name)


        Saves an ArcGISProject (.aprx) to a new file path or name.


        file_name(String):
        A string used to save an ArcGISProject (.aprx) to a new file path or
        file name.
        """
        return convertArcObjectToPythonObject(self._arc_object.saveACopy(*gp_fixargs((file_name,), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True, ignore_case=False):
        """ArcGISProject.updateConnectionProperties(current_connection_info,
        new_connection_info, {auto_update_joins_and_relates}, {validate},
        {ignore_case})


        The updateConnectionProperties method replaces connection properties
        using a dictionary or a path to a workspace.


        current_connection_info(String):
        A string that represents the workspace path or a Python dictionary that
        contains connection properties to the source you want to update. If an
        empty string or None is used in current_connection_info, all connection
        properties will be replaced with the new_workspace_info, depending on
        the value of the validate parameter.


        new_connection_info(String):
        A string that represents the workspace path or a Python dictionary that
        contains connection properties with the new source information.


        auto_update_joins_and_relates{Boolean}:
        If  set to True, the updateConnectionProperties method will also update
        the connections for associated joins or relates. The default value is
        True.


        validate{Boolean}:
        If  set to True, the connection properties will only be updated if the
        new_connection_info value is a valid connection.  If it is not valid,
        the connection will not be replaced.   If set to False, the method will
        set all connections to match the new_connection_info value, regardless
        of a valid match.  In this case, if a match does not exist, the data
        sources would be broken. The default value is True.


        ignore_case{Boolean}:
        Determines whether searches will be case sensitive. By default, queries
        are case sensitive. To perform queries that are not case sensitive, set
        ignore_case to True. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate, ignore_case), True)))

    def listColorRamps(self, wildcard=None):
        """ArcGISProject.listColorRamps({wildcard})


        The listColorRamps method references color ramps  available in a
        project.


        wildcard{String}:
        A wildcard is based on the color ramp name as it appears in the
        application.  A combination of asterisks (*) and characters can be used
        to help
        limit the resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listColorRamps(*gp_fixargs((wildcard,), True)))

    @constants.maskargs
    def closeViews(self, view_type='MAPS_AND_LAYOUTS'):
        """ArcGISProject.closeViews({view_type})


        Close view panes that are currently open in  ArcGIS Pro.


        view_type{String}:
        A constant that determines the type of views to be closed in the
        application. The default value is MAPS_AND_LAYOUTS.

        * MAPS: Close all open map view panes.

        * LAYOUTS: Close all open layout view panes.

        * REPORTS: Close all open report view panes.

        * MAPS_AND_LAYOUTS: Close all open layout and map view panes.
        """
        return convertArcObjectToPythonObject(self._arc_object.closeViews(*gp_fixargs((view_type,), True)))

    @constants.maskargs
    def createMap(self, name=None, map_type="Map"):
        """ArcGISProject.createMap({name}, {map_type})


        This method creates a map that will automatically get added to the
        Catalog pane.


        name{String}:
        A string that represents the name of the new map.  If a name is not
        provided, the default name will follow the sequencing nomenclature, for
        example, Map, Map1, Map2.


        map_type{String}:
        The type of map to be created and are defined by the keywords below. The
        default value is Map.

        * MAP: A new map

        * GLOBE: A new global scene

        * SCENE: A new local scene
        """
        return convertArcObjectToPythonObject(self._arc_object.createMap(*gp_fixargs((name, map_type,), True)))

    @constants.maskargs
    def createLayout(self, page_width, page_height, page_units, name=None):
        """ArcGISProject.createLayout(page_width, page_height, page_units, {name})


        The createLayout method creates a layout that will automatically get
        added to the Catalog pane.


        page_width(Double):
        A double that specifies the width of a layout and is based on the
        page_units.


        page_height(Double):
        A double that specifies the height of a layout and is based on the
        page_units.


        page_units(String):
        One of the following page units must be provided to describe the width
        and height values.

        * INCH: Page units are in inches.

        * MILLIMETER: Page units are in millimeters.

        * CENTIMETER: Page units are in centimeters.

        * POINT: Page units are in points where 72 points is 1 inch or 2.54
        centimeters.


        name{String}:
        A string that represents the name of the new layout.  If a name is not
        provided, the default name will follow the sequencing nomenclature, for
        example, Layout, Layout1, Layout2.
        """
        return convertArcObjectToPythonObject(self._arc_object.createLayout(*gp_fixargs((page_width, page_height, page_units, name,), True)))

    def copyItem(self, project_item, new_name=None):
        """ArcGISProject.copyItem(project_item, {new_name})


        Creates a copy of an existing layout, map, or report project item.


        project_item(Object):
        An object that represents a supported project item to be copied.


        new_name{String}:
        A string that represents the name of the new project item.  If a name is
        not provided, the default name will follow the sequencing nomenclature,
        for example, Map, Map1, Map2.
        """
        return convertArcObjectToPythonObject(self._arc_object.copyItem(*gp_fixargs((project_item, new_name,), True)))

    def deleteItem(self, project_item):
        """ArcGISProject.deleteItem(project_item)


        Deletes a layout, map, or report project item.


        project_item(Object):
        An object that represents a supported project item to be deleted.
        """
        return convertArcObjectToPythonObject(self._arc_object.deleteItem(*gp_fixargs((project_item,), True)))

    def updateFolderConnections(self, folder_connections, validate=True):
        """ArcGISProject.updateFolderConnections(folder_connections, {validate})


        Replaces project folder connections using a list of dictionaries that
        describe each connection.


        folder_connections(List):
        A list of Python dictionaries that each contain connection properties to
        an individual folder.  The dictionary keys are defined below.

        * alias: An alternative label for a folder connection. If left as an
        empty string, the alias will match the connectionString value.

        * connectionString: A local or UNC path to a system folder.

        * isHomeFolder: The default home folder.  One and only one folder must
        be set to True. Note: It is possible for administrators to set the home
        folder to be read-only.  If that is that case, this setting will be
        ignored.


        validate{Boolean}:
        If  set to True, the folder will only be added if the  connectionString
        is a valid path.  If it is not valid, the folder will not be added and
        the function will return the dictionary as an invalid folder.   If set
        to False, the method will set all connections to match the
        connectionString, regardless of a valid match.  In this case, if a match
        does not exist, the folder will be added but will appear as broken. The
        default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.updateFolderConnections(*gp_fixargs((folder_connections, validate), True)))

    def __init__(self, aprx_path):
        """ArcGISProject(aprx_path)


        Provides a reference to an ArcGIS project ( .aprx ) stored on disk or to the
        project currently loaded within the ArcGIS Pro application using the
        CURRENT keyword.


        aprx_path(String):
        A string that includes the full system path and file name of an existing ArcGIS
        project (.aprx) or a string that contains the CURRENT keyword.
        """
        import arcgisscripting
        self._arc_object = arcgisscripting._mapping.ArcGISProject(*gp_fixargs((aprx_path,), True))

class Bookmark(_ObjectWithoutInitCall):
    """Provides access to bookmark methods and properties."""
    hasThumbnail = passthrough_attr('hasThumbnail')
    map = passthrough_attr('map')
    name = passthrough_attr('name')
    def updateThumbnail(self):
        """Bookmark.updateThumbnail()


        Updates a bookmark's thumbnail image.
        """
        return convertArcObjectToPythonObject(self._arc_object.updateThumbnail(*gp_fixargs((), True)))

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isBookmarkSame(*gp_fixargs((other,), True)))

class Camera(_ObjectWithoutInitCall):
    """The Camera object provides access to  2D and 3D viewer properties that
       control the display in a MapFrame ."""
    heading = passthrough_attr('heading')
    mode = passthrough_attr('mode')
    pitch = passthrough_attr('pitch')
    roll = passthrough_attr('roll')
    scale = passthrough_attr('scale')
    X = passthrough_attr('X')
    Y = passthrough_attr('Y')
    Z = passthrough_attr('Z')
    def getExtent(self):
        """Camera.getExtent()


        Returns an Extent object for a 2D map frame.
        """
        return convertArcObjectToPythonObject(self._arc_object.getExtent(*gp_fixargs((), True)))

    def setExtent(self, extent):
        """Camera.setExtent(extent)


        Sets the Extent for a map frame in a layout.


        extent(Extent):
        A geoprocessing Extent object.
        """
        return convertArcObjectToPythonObject(self._arc_object.setExtent(*gp_fixargs((extent,), True)))

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isCameraSame(*gp_fixargs((other,), True)))

class GraphicElement(_ObjectWithoutInitCall):
    """The GraphicElement object provides access to properties that enables its
       repositioning on the page layout, as well as methods that allow for
       duplicating and deleting existing graphic elements."""
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementRotation = passthrough_attr('elementRotation')
    elementWidth = passthrough_attr('elementWidth')
    isGroup = passthrough_attr('isGroup')
    locked = passthrough_attr('locked')
    name = passthrough_attr('name')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
    def clone(self, suffix=None):
        """GraphicElement.clone({suffix})


        Provides a mechanism to clone an existing graphic element on a page
        layout.


        suffix{String}:
        An optional string that is used to tag each newly created graphic
        element.  The new element will get the same element name as the parent
        graphic plus the suffix value along with  a numeric sequencer.  For
        example, if the parent element name is Line and the suffix value is
        _copy, the newly cloned elements are named  Line_copy, Line_copy_1,
        Line_copy_2, and so on.  If a suffix is not provided, the results
        resemble Line_1, Line_2, Line_3, and so on.
        """
        return convertArcObjectToPythonObject(self._arc_object.clone(*gp_fixargs((suffix,), True)))

    def delete(self):
        """GraphicElement.delete()


        Provides a mechanism to delete an existing graphic element on a page
        layout.
        """
        return convertArcObjectToPythonObject(self._arc_object.delete(*gp_fixargs((), True)))

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isGraphicElementSame(*gp_fixargs((other,), True)))

class LabelClass(_ObjectWithoutInitCall):
    """Provides access to a layer's label class properties."""
    expression = passthrough_attr('expression')
    name = passthrough_attr('name')
    SQLQuery = passthrough_attr('SQLQuery')
    visible = passthrough_attr('visible')

class Layer(_ObjectWithoutInitCall):
    """Layer(lyr_file_path)


    References a layer file stored on disk.


    lyr_file_path(String):
    A string that includes the full path and file name of an existing layer
    file.  The supported extensions are .lyr or .lyrx.
    """
    brightness = passthrough_attr('brightness')
    contrast = passthrough_attr('contrast')
    connectionProperties = passthrough_attr('connectionProperties', True)
    dataSource = passthrough_attr('dataSource', True)
    definitionQuery = passthrough_attr('definitionQuery')
    is3DLayer = passthrough_attr('is3DLayer')
    isBroken = passthrough_attr('isBroken')
    isFeatureLayer = passthrough_attr('isFeatureLayer')
    isSceneLayer = passthrough_attr('isSceneLayer')
    isBasemapLayer = passthrough_attr('isBasemapLayer')
    isGroupLayer = passthrough_attr('isGroupLayer')
    isNetworkAnalystLayer = passthrough_attr('isNetworkAnalystLayer')
    isNetworkDatasetLayer = passthrough_attr('isNetworkDatasetLayer')
    isRasterLayer = passthrough_attr('isRasterLayer')
    isWebLayer = passthrough_attr('isWebLayer')
    isTimeEnabled = passthrough_attr('isTimeEnabled')
    longName = passthrough_attr('longName')
    maxThreshold = passthrough_attr('maxThreshold')
    minThreshold = passthrough_attr('minThreshold')
    name = passthrough_attr('name')
    showLabels = passthrough_attr('showLabels')
    transparency = passthrough_attr('transparency')
    visible = passthrough_attr('visible')
    symbology = passthrough_attr('symbology')
    metadata = passthrough_attr('metadata')
    time = passthrough_attr('time')
    URI = passthrough_attr('URI')

    @constants.maskargs
    def extrusion(self, extrusion_type='NONE', expression=None):
        """Layer.extrusion({extrusion_type}, {expression})


        Extrudes 2D features in a layer to display 3D symbology.


        extrusion_type{String}:
        A string that specifies the extrusion method.  The default value is NONE
        which turns off layer extrusion. The default value is NONE.

        * ABSOLUTE_HEIGHT: The feature is extruded to the specified z-value, as
        a flat top, regardless of the z-values of the feature.

        * MIN_HEIGHT: Adds extrusion height to the minimum z-value of the
        feature, and the feature is extruded to a flat top at that value.

        * NONE: Features are not extruded.

        * BASE_HEIGHT: A z-value is calculated for each vertex of the feature's
        base, and the feature is extruded to the various z-values creating a
        multifaceted top.

        * MAX_HEIGHT: Adds extrusion height to the minimum z-value of the
        feature, and the feature is extruded to a flat top at that value.


        expression{String}:
        A string that defines the extrusion expression, which provides an
        absolute extrusion height  for each feature. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.extrusion(*gp_fixargs((extrusion_type, expression), True)))

    def getSelectionSet(self):
        """Layer.getSelectionSet()


        Returns a layer's selection as a Python set of object IDs.
        """
        return convertArcObjectToPythonObject(self._arc_object.getSelectionSet(*gp_fixargs((), True)))

    def listLabelClasses(self, wildcard=None):
        """Layer.listLabelClasses({wildcard})


        Returns a Python list of LabelClass objects in a layer.


        wildcard{String}:
        A wildcard is based on the label class name and is not case sensitive. A
        combination of asterisks (*) and characters can be used to help
        limit the resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listLabelClasses(*gp_fixargs((wildcard,), True)))

    def listLayers(self, wildcard=None):
        """Layer.listLayers({wildcard})


        Returns a Python list of Layer objects from  a group layer or composite
        layer.


        wildcard{String}:
        A wildcard is based on the layer name and is not case sensitive. A
        combination of asterisks (*) and characters can be used to help
        limit the resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listLayers(*gp_fixargs((wildcard,), True)))

    def listTables(self, wildcard=None):
        """Layer.listTables({wildcard})


        Returns a Python list of Table objects that exist within a group layer.


        wildcard{String}:
        A wildcard is based on the table name and is not case sensitive.  A
        combination of asterisks (*) and characters can be used to limit the
        resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listTables(*gp_fixargs((wildcard,), True)))

    def listDefinitionQueries(self, wildcard=None):
        """Layer.listDefinitionQueries({wildcard})


        Returns a Python list of definition queries associated with a layer.


        wildcard{String}:
        A wildcard is based on the query name and is not case sensitive.  A
        combination of asterisks (*) and characters can be used to limit the
        resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listDefinitionQueries(*gp_fixargs((wildcard,), True)))

    def saveACopy(self, file_name):
        """Layer.saveACopy(file_name)


        Saves a layer to a layer file (.lyrx).


        file_name(String):
        A string that includes the location and name of the output layer file
        (.lyrx).
        """
        return convertArcObjectToPythonObject(self._arc_object.saveACopy(*gp_fixargs((file_name,), True)))

    @constants.maskargs
    def setSelectionSet(self, oidList=None, method='NEW'):
        """Layer.setSelectionSet({oidList}, {method})


        Sets a layer's selection using a Python list of Object IDs.


        oidList{Integer}:
        A Python list of Object IDs to use along with the appropriate selection
        method. The default value is None.


        method{String}:
        A string that specifies which selection method to use. The default value
        is NEW.

        * UNION: Selects all the features in both the current selection and
        those in the oidList.

        * NEW: Creates a new feature selection from the oidList.

        * DIFFERENCE: Selects the features that are not in the current selection
        but are in the oidList.

        * SYMDIFFERENCE: Selects the features that are in the current selection
        or the oidList but not both.

        * INTERSECT: Selects the features that are in the current selection and
        the oidList.
        """
        return convertArcObjectToPythonObject(self._arc_object.setSelectionSet(*gp_fixargs((oidList, method), True)))

    def supports(self, layer_property):
        """Layer.supports(layer_property)


        Used to determine if a particular layer type supports a property on the
        layer object.  Not all layers support the same set of properties; the
        supports property can be used to test if a layer supports that property
        before attempting to set it.


        layer_property(String):
        The name of a particular layer property that will be tested. The default
        value is name.

        * SYMBOLOGY: A layer that symbology can be accessed.

        * NAME: A layer's name.

        * BRIGHTNESS: A raster layer's brightness value.

        * SHOWLABELS: A layer that can display labels.

        * MINTHRESHOLD: A layer's minimum threshold to display the features.

        * LONGNAME: A layer's path including the group layers it may be nested
        within.

        * URI: A layer's Universal Resource Identifier.

        * MAXTHRESHOLD: A layer's maximum threshold to display the features.

        * VISIBLE: A layer's visibility state.

        * DEFINITIONQUERY: A layer's definition query string.

        * DATASOURCE: A layer's file path or connection file.

        * TRANSPARENCY: A layer's transparency value.

        * TIME: A layer's time properties.

        * CONNECTIONPROPERTIES: A Layer's connection information.

        * CONTRAST: A raster layer's contrast value

        * METADATA: A layer that can persist metadata.
        """
        return convertArcObjectToPythonObject(self._arc_object.supports(*gp_fixargs((layer_property,), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True, ignore_case=False):
        """Layer.updateConnectionProperties(current_connection_info,
        new_connection_info, {auto_update_joins_and_relates}, {validate},
        {ignore_case})


        The updateConnectionProperties method replaces connection properties
        using a dictionary or a path to a workspace.


        current_connection_info(String):
        A string that represents the workspace path or a Python dictionary that
        contains connection properties to the source you want to update. If an
        empty string or None is used in current_connection_info, all connection
        properties will be replaced with the new_workspace_info, depending on
        the value of the validate parameter.


        new_connection_info(String):
        A string that represents the workspace path or a Python dictionary that
        contains connection properties with the new source information.


        auto_update_joins_and_relates{Boolean}:
        If  set to True, the updateConnectionProperties method will also update
        the connections for associated joins or relates. The default value is
        True.


        validate{Boolean}:
        If  set to True, the connection properties will only be updated if the
        new_connection_info value is a valid connection.  If it is not valid,
        the connection will not be replaced.   If set to False, the method will
        set all connections to match the new_connection_info value, regardless
        of a valid match.  In this case, if a match does not exist, the data
        sources would be broken. The default value is True.


        ignore_case{Boolean}:
        Determines whether searches will be case sensitive. By default, queries
        are case sensitive. To perform queries that are not case sensitive, set
        ignore_case to True. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate, ignore_case), True)))

    def updateDefinitionQueries(self, definitionQueries):
        """Layer.updateDefinitionQueries(definitionQueries)


        Updates a layer's collection of definition queries.


        definitionQueries(List):
        Updates a list of dictionaries that represent the properties of each
        definition query.
        """
        return convertArcObjectToPythonObject(self._arc_object.updateDefinitionQueries(*gp_fixargs((definitionQueries,), True)))

    def updateLayerFromJSON(self, json_data):
        """Layer.updateLayerFromJSON(json_data)


        Updates a Layer from a JSON string.


        json_data(String):
        The layer definition in JavaScript Object Notation (JSON) format. See
        the ExportWebMap JSON specification for more information. ArcGIS API for
        JavaScript and ArcGIS Web AppBuilder allow you to get this JSON string
        from the web app. The layer definition is a subset of the webmap_json
        used in the ConvertWebMapToArcGISProject function. You don't need to
        create the web map JSON; the APIs take care of it for you. However, you
        need to extract the layer definition from the full webmap_json.
        """
        return convertArcObjectToPythonObject(self._arc_object.UpdateLayerFromJSON(*gp_fixargs((json_data,), True)))

    def enableTime(self, startTimeField=None, endTimeField=None, autoCalculateTimeRange=True, timeDimension=None):
        """Layer.enableTime({startTimeField}, {endTimeField},
        {autoCalculateTimeRange}, {timeDimension})


        Enables time on a layer if it has time information.


        startTimeField{String}:
        The name of the field containing the start time values. If each feature
        has a single time field, specify that field name in the startTimeField
        and leave endTimeField blank. If each feature has a start and end time
        field, specify both the  startTimeField and endTimeField. The default
        value is None.


        endTimeField{String}:
        The name of the field containing the end time values. Not all layers use
        an end time field. If each feature has a single time field, specify that
        field name in the startTimeField and leave endTimeField blank. If each
        feature has a start and end time field, specify both the  startTimeField
        and endTimeField. The default value is None.


        autoCalculateTimeRange{Boolean}:
        If  set to True, the start and end time attribute information is used to
        calculate the layer's time extent. The default value is True.


        timeDimension{String}:
        The name of the dimension containing time values when using netCDF data.
        The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.enableTime(*gp_fixargs((startTimeField, endTimeField, autoCalculateTimeRange, timeDimension), True)))

    def disableTime(self):
        """Layer.disableTime()


        Disables time on a layer.
        """
        return convertArcObjectToPythonObject(self._arc_object.disableTime(*gp_fixargs((), True)))

    def __str__(self):
        return self.longName

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isLayerSame(*gp_fixargs((other,), True)))

    @constants.maskargs
    def getDefinition(self, cim_version):
        """Layer.getDefinition(cim_version)


        Gets a layer's CIM definition.


        cim_version(String):
        A string that represents the major version of the CIM.
        """
        from .cim.cimloader import GetJSONTypeOBJ
        import json
        return GetJSONTypeOBJ(json.loads(convertArcObjectToPythonObject(self._arc_object.GetCimJSONString(*gp_fixargs((cim_version,), True)))))

    @constants.maskargs
    def setDefinition(self, definition_object):
        """Layer.setDefinition(definition_object)


        Sets a layer's CIM definition.


        definition_object(Object):
        A modified CIM definition object originally retrieved using
        getDefinition.
        """
        from .cim.cimloader import  CimJsonEncoder
        import json
        json_data = json.dumps(definition_object, cls=CimJsonEncoder)
        return convertArcObjectToPythonObject(self._arc_object.SetCimJSONString(json_data))

class LayerFile(_ObjectWithoutInitCall):
    """LayerFile(layer_file_path)


    References a layer file (.lyr or .lyrx) stored on disk.


    layer_file_path(String):
    A string that includes the full system path and file name of an existing
    layer file.
    """
    filePath = passthrough_attr('filePath')
    version = passthrough_attr('version')
    metadata = passthrough_attr('metadata')

    @constants.maskargs
    def addLayer(self, add_layer_or_layerfile, add_position='AUTO_ARRANGE'):
        """LayerFile.addLayer(add_layer_or_layerfile, {add_position})


        Provides the ability to add a Layer or LayerFile to a layer file
        (.lyrx) using basic placement options.


        add_layer_or_layerfile(Layer):
        A reference to a Layer or LayerFile object representing the layer or
        layers  to be added.


        add_position{String}:
        A constant that determines the placement of the added layer or layers
        in a layer file. The default value is AUTO_ARRANGE.

        * TOP: Places the layer or layers at the top of the TOC layer stack.

        * AUTO_ARRANGE: Automatically places the layer or layers based on its
        layer weight rules and geometry.

        * BOTTOM: Places the layer or layers at the bottom of the TOC layer
        stack.
        """
        return convertArcObjectToPythonObject(self._arc_object.addLayer(*gp_fixargs((add_layer_or_layerfile, add_position), True)))

    @constants.maskargs
    def addLayerToGroup(self, target_group_layer, add_layer_or_layerfile, add_position='AUTO_ARRANGE'):
        """LayerFile.addLayerToGroup(target_group_layer, add_layer_or_layerfile,
        {add_position})


        Provides the ability to add a Layer or the contents of a LayerFile to an
        existing group layer in a layer file (.lyrx) using basic placement
        options.


        target_group_layer(Layer):
        A reference to an existing group Layer object.


        add_layer_or_layerfile(Layer):
        A reference to a Layer or LayerFile object representing the layer or
        layers  to be added.


        add_position{String}:
        A constant that determines the placement of the added layer or layers in
        the target_group_layer. The default value is AUTO_ARRANGE.

        * TOP: Places the layer at the top of the TOC layer stack.

        * AUTO_ARRANGE: Automatically places the layer based on its layer weight
        rules and geometry.

        * BOTTOM: Places the layer at the bottom of the TOC layer stack.
        """
        return convertArcObjectToPythonObject(self._arc_object.addLayerToGroup(*gp_fixargs((target_group_layer, add_layer_or_layerfile, add_position), True)))

    @constants.maskargs
    def insertLayer(self, reference_layer, insert_layer_or_layerfile, insert_position='BEFORE'):
        """LayerFile.insertLayer(reference_layer, insert_layer_or_layerfile,
        {insert_position})


        Provides the ability to add a Layer or LayerFile into a layer file
        (.lyrx) by specifying  a location.


        reference_layer(Layer):
        A Layer object representing an existing layer that determines the
        location where the new layer will be inserted.


        insert_layer_or_layerfile(Layer):
        A reference to a Layer or LayerFile object representing the layer or
        layers  to be added.


        insert_position{String}:
        A constant that determines the placement of the added layer or layers
        relative to the reference_layer. The default value is BEFORE.

        * AFTER: Inserts the new layer after or below the reference layer.

        * BEFORE: Inserts the new layer before or above the reference layer.
        """
        return convertArcObjectToPythonObject(self._arc_object.insertLayer(*gp_fixargs((reference_layer, insert_layer_or_layerfile, insert_position), True)))

    def listBrokenDataSources(self):
        """LayerFile.listBrokenDataSources()


        Returns a Python list of Layer objects in a layer file that have broken
        connections to their original source data.
        """
        return convertArcObjectToPythonObject(self._arc_object.listBrokenDataSources(*gp_fixargs((), True)))

    def listLayers(self, wildcard=None):
        """LayerFile.listLayers({wildcard})


        Returns a Python list of Layers in a layer file.


        wildcard{String}:
        A wildcard is based on the layer name and is not case sensitive. A
        combination of asterisks (*) and characters can be used to help
        limit the resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listLayers(*gp_fixargs((wildcard,), True)))

    def listTables(self, wildcard=None):
        """LayerFile.listTables({wildcard})


        Returns a Python list of Table objects that exist within a LayerFile.


        wildcard{String}:
        A wildcard is based on the table name and is not case sensitive.  A
        combination of asterisks (*) and characters can be used to limit the
        resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listTables(*gp_fixargs((wildcard,), True)))

    @constants.maskargs
    def moveLayer(self, reference_layer, move_layer, insert_position='BEFORE'):
        """LayerFile.moveLayer(reference_layer, move_layer, {insert_position})


        Provides the ability to move a layer or group layer in a layer file to
        a specific location in the layer stack.


        reference_layer(Layer):
        A Layer  object representing an existing layer that determines the
        location where the new layer will be moved.


        move_layer(Layer):
        A reference to a Layer object representing the layer to be moved.


        insert_position{String}:
        A constant that determines the placement of the moved layer relative to
        the reference layer. The default value is BEFORE.

        * AFTER: Moves the  layer after or below the reference layer.

        * BEFORE: Moves the layer before or above the reference layer.
        """
        return convertArcObjectToPythonObject(self._arc_object.moveLayer(*gp_fixargs((reference_layer, move_layer, insert_position), True)))

    def removeLayer(self, remove_layer):
        """LayerFile.removeLayer(remove_layer)


        Provides the ability to remove a layer from a layer file.


        remove_layer(Layer):
        A reference to a Layer object representing the layer to be removed.
        """
        return convertArcObjectToPythonObject(self._arc_object.removeLayer(*gp_fixargs((remove_layer,), True)))

    def save(self):
        """LayerFile.save()


        Saves an existing layer file reference to a .lyrx file, even if the file
        referenced was a .lyr file.
        """
        return convertArcObjectToPythonObject(self._arc_object.save(*gp_fixargs((), True)))

    def saveACopy(self, file_name):
        """LayerFile.saveACopy(file_name)


        Saves a LayerFile  to a new path or file name.


        file_name(String):
        A string used to save a LayerFile to a new path or file name.  You can
        only save to .lyrx files.
        """
        return convertArcObjectToPythonObject(self._arc_object.saveACopy(*gp_fixargs((file_name,), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True, ignore_case=False):
        """LayerFile.updateConnectionProperties(current_connection_info,
        new_connection_info, {auto_update_joins_and_relates}, {validate},
        {ignore_case})


        The updateConnectionProperties method replaces connection properties
        using a dictionary or a path to a workspace.


        current_connection_info(String):
        A string that represents the workspace path or a Python dictionary that
        contains connection properties to the source you want to update. If an
        empty string or None is used in current_connection_info, all connection
        properties will be replaced with the new_workspace_info, depending on
        the value of the validate parameter.


        new_connection_info(String):
        A string that represents the workspace path or a Python dictionary that
        contains connection properties with the new source information.


        auto_update_joins_and_relates{Boolean}:
        If  set to True, the updateConnectionProperties method will also update
        the connections for associated joins or relates. The default value is
        True.


        validate{Boolean}:
        If  set to True, the connection properties will only be updated if the
        new_connection_info value is a valid connection.  If it is not valid,
        the connection will not be replaced.   If set to False, the method will
        set all connections to match the new_connection_info value, regardless
        of a valid match.  In this case, if a match does not exist, the data
        sources would be broken. The default value is True.


        ignore_case{Boolean}:
        Determines whether searches will be case sensitive. By default, queries
        are case sensitive. To perform queries that are not case sensitive, set
        ignore_case to True. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate, ignore_case), True)))

    def __init__(self, layer_file_path):
        """LayerFile(layer_file_path)


        References a layer file ( .lyr or .lyrx ) stored on disk.


        layer_file_path(String):
        A string that includes the full system path and file name of an existing layer file.
        """
        import arcgisscripting
        self._arc_object = arcgisscripting._mapping.LayerFile(*gp_fixargs((layer_file_path,), True))

    def __str__(self):
        return self.filePath

class LayerTime(_ObjectWithoutInitCall):
    """LayerTime provides access to layer time level information in a Layer Object."""
    startTimeField = passthrough_attr('startTimeField')
    endTimeField = passthrough_attr('endTimeField')
    timeFormat = passthrough_attr('timeFormat')
    startTime = passthrough_attr('startTime')
    endTime = passthrough_attr('endTime')
    timeZone = passthrough_attr('timeZone')
    daylightSavings = passthrough_attr('daylightSavings')
    timeOffset = passthrough_attr('timeOffset')
    timeOffsetUnits = passthrough_attr('timeOffsetUnits')
    timeStepInterval = passthrough_attr('timeStepInterval')
    timeStepIntervalUnits = passthrough_attr('timeStepIntervalUnits')
    timeDimension = passthrough_attr('timeDimension')

class Layout(_ObjectWithoutInitCall):
    """The Layout object references a single-page layout in an ArcGIS Pro
       project ( .aprx ).  It provides access to common properties like page
       size and a number of different export methods."""
    name = passthrough_attr('name')
    pageHeight = passthrough_attr('pageHeight')
    pageUnits = passthrough_attr('pageUnits')
    pageWidth = passthrough_attr('pageWidth')
    mapSeries = passthrough_attr('mapSeries')
    metadata = passthrough_attr('metadata')
    URI = passthrough_attr('URI')

    @constants.maskargs
    def exportToAIX(self, out_aix, resolution=300, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', jpeg_compression_quality=80, embed_fonts=True, embed_color_profile=True, clip_to_elements=False, keep_layout_background=True):
        """Layout.exportToAIX(out_aix, {resolution}, {image_quality},
        {compress_vector_graphics}, {image_compression},
        {jpeg_compression_quality}, {embed_fonts}, {embed_color_profile},
        {clip_to_elements}, {keep_layout_background})


        Exports the  Layout  to Adobe Illustrator Exchange (AIX) format. AIX
        files can be used with the ArcGIS Maps for Adobe Creative Cloud
        extension or Adobe Illustrator.


        out_aix(String):
        A string that represents the path and file name for the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 300.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2

        * NORMAL: An output image quality resample ratio of 3

        * FASTEST: An output image quality resample ratio of 5

        * BEST: An output image quality resample ratio of 1

        * FASTER: An output image quality resample ratio of 4


        compress_vector_graphics{Boolean}:
        A Boolean that controls compression of vector and text portions of the
        output file. Image compression is defined separately. The default value
        is True.


        image_compression{String}:
        A string that specifies the compression scheme used to compress image or
        raster data in the output file. The default value is ADAPTIVE.

        * DEFLATE: A lossless data compression.

        * NONE: Compression is not applied.

        * RLE: Run-length encoded compression.

        * JPEG: A lossy data compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.

        * ADAPTIVE: Automatically selects the best compression type for each
        image on the page.   JPEG will be used for large images with many unique
        colors.  DEFLATE will be used for all other images.


        jpeg_compression_quality{Integer}:
        A number that controls compression quality value when image_compression
        is set to ADAPTIVE or JPEG. The valid range is 1 through 100.    A
        jpeg_compression_quality of 100 provides the best-quality images but
        creates large export files.   The recommended range is between 70 and
        90. The default value is 80.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in the export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.


        clip_to_elements{Boolean}:
        If set to True, the layout is clipped to the smallest bounding box that
        includes all layout elements. The default value is False.


        keep_layout_background{Boolean}:
        If set to True, the layout's white background will be kept. The default
        value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToAIX(*gp_fixargs((out_aix, resolution, image_quality, compress_vector_graphics, image_compression, jpeg_compression_quality, embed_fonts, embed_color_profile, clip_to_elements, keep_layout_background), True)))

    @constants.maskargs
    def exportToBMP(self, out_bmp, resolution=96, bmp_color_mode='24-BIT_TRUE_COLOR', bmp_image_compression='NONE', embed_color_profile=True, clip_to_elements=False):
        """Layout.exportToBMP(out_bmp, {resolution}, {bmp_color_mode},
        {bmp_image_compression}, {embed_color_profile}, {clip_to_elements})


        Exports the Layout to the Microsoft Windows Bitmap format (BMP).


        out_bmp(String):
        A string that represents the path and file name for the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        bmp_color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 24-BIT_TRUE_COLOR.

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 24-BIT_TRUE_COLOR: 24-bit true color


        bmp_image_compression{String}:
        A string that specifies the compression scheme used to compress image or
        raster data in the output file.  This option only applies to 8-bit
        bmp_color_mode options. The default value is NONE.

        * RLE: Run-length encoded compression.

        * NONE: Compression is not applied.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.


        clip_to_elements{Boolean}:
        If set to True, the layout is clipped to the smallest bounding box that
        includes all layout elements. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToBMP(*gp_fixargs((out_bmp, resolution, bmp_color_mode, bmp_image_compression, embed_color_profile, clip_to_elements), True)))

    @constants.maskargs
    def exportToEMF(self, out_emf, resolution=96, image_quality='BEST', output_as_image=False, clip_to_elements=False):
        """Layout.exportToEMF(out_emf, {resolution}, {image_quality},
        {output_as_image}, {clip_to_elements})


        Exports the Layout to the Enhanced Metafile (EMF) format.


        out_emf(String):
        A string that represents the system path and file name for the output
        export file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2

        * NORMAL: An output image quality resample ratio of 3

        * FASTEST: An output image quality resample ratio of 5

        * BEST: An output image quality resample ratio of 1

        * FASTER: An output image quality resample ratio of 4


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.


        clip_to_elements{Boolean}:
        If set to True, the layout is clipped to the smallest bounding box that
        includes all layout elements. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToEMF(*gp_fixargs((out_emf, resolution, image_quality, output_as_image, clip_to_elements), True)))

    @constants.maskargs
    def exportToEPS(self, out_eps, resolution=96, image_compression='DEFLATE', image_quality='BEST',
                   embed_fonts=True, output_as_image=False, clip_to_elements=False):
        """Layout.exportToEPS(out_eps, {resolution}, {image_compression},
        {image_quality}, {embed_fonts}, {output_as_image}, {clip_to_elements})


        Exports the Layout to an Encapsulated PostScript (EPS) format file.


        out_eps(String):
        A string that represents the system path and file name for the output
        export file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        image_compression{String}:
        A string that specifies the compression scheme used to compress image or
        raster data in the output file. The default value is DEFLATE.

        * RLE: Run-length encoded compression.

        * NONE: Compression is not applied.

        * DEFLATE: A lossless data compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2.

        * NORMAL: An output image quality resample ratio of 3.

        * FASTEST: An output image quality resample ratio of 5.

        * BEST: An output image quality resample ratio of 1.

        * FASTER: An output image quality resample ratio of 4.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in the export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.


        clip_to_elements{Boolean}:
        If set to True, the layout is clipped to the smallest bounding box that
        includes all layout elements. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToEPS(*gp_fixargs((out_eps, resolution, image_compression, image_quality, embed_fonts, output_as_image, clip_to_elements), True)))

    @constants.maskargs
    def exportToGIF(self, out_gif, resolution=96, gif_color_mode='8-BIT_ADAPTIVE_PALETTE',
                    clip_to_elements=False):
        """Layout.exportToGIF(out_gif, {resolution}, {gif_color_mode},
        {clip_to_elements})


        Exports the Layout to Graphic Interchange Format (GIF).


        out_gif(String):
        A string that represents the system path and file name for the output
        export file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        gif_color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 8-BIT_PALETTE.

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette

        * 8-BIT_GRAYSCALE: 8-bit grayscale


        clip_to_elements{Boolean}:
        If set to True, the layout is clipped to the smallest bounding box that
        includes all layout elements. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToGIF(*gp_fixargs((out_gif, resolution, gif_color_mode, clip_to_elements), True)))

    @constants.maskargs
    def exportToJPEG(self, out_jpg, resolution=96, jpeg_color_mode='24-BIT_TRUE_COLOR', jpeg_quality=80, embed_color_profile=True, clip_to_elements=False):
        """Layout.exportToJPEG(out_jpg, {resolution}, {jpeg_color_mode},
        {jpeg_quality}, {embed_color_profile}, {clip_to_elements})


        Exports the Layout to a Joint Photographic Experts Group (JPEG) format
        file.


        out_jpg(String):
        A string that represents the path and file name of the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        jpeg_color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 24-BIT_TRUE_COLOR.

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 24-BIT_TRUE_COLOR: 24-bit true color


        jpeg_quality{Integer}:
        This value (0–100) controls the amount of compression applied to the
        output image. With a JPEG image, quality is adversely affected the more
        compression is applied. A higher quality (highest = 100) setting will
        produce sharper images and larger file sizes. A lower quality setting
        will produce more image artifacts and smaller files. The default value
        is 80.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.


        clip_to_elements{Boolean}:
        If set to True, the layout is clipped to the smallest bounding box that
        includes all layout elements. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToJPEG(*gp_fixargs((out_jpg, resolution, False, jpeg_color_mode, jpeg_quality, embed_color_profile, clip_to_elements), True)))

    def exportToPAGX(self, out_pagx):
        from os import remove
        from os.path import isfile
        if isfile(out_pagx):
            remove(out_pagx)

        """Layout.exportToPAGX(out_pagx)


        Exports a layout to a page file.


        out_pagx(String):
        A string used to save a layout to a page file (.pagx).
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToPAGX(*gp_fixargs((out_pagx,), True)))

    @constants.maskargs
    def exportToPDF(self, out_pdf, resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, layers_attributes='LAYERS_ONLY', georef_info=True, jpeg_compression_quality=80, clip_to_elements=False, output_as_image= False, embed_color_profile=True, pdf_accessibility=False):
        """Layout.exportToPDF(out_pdf, {resolution}, {image_quality},
        {compress_vector_graphics}, {image_compression}, {embed_fonts},
        {layers_attributes}, {georef_info}, {jpeg_compression_quality},
        {clip_to_elements}, {output_as_image}, {embed_color_profile},
        {pdf_accessibility})


        Exports the Layout  to Portable Document Format (PDF).


        out_pdf(String):
        A string that represents the path and file name for the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 300.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2

        * NORMAL: An output image quality resample ratio of 3

        * FASTEST: An output image quality resample ratio of 5

        * BEST: An output image quality resample ratio of 1

        * FASTER: An output image quality resample ratio of 4


        compress_vector_graphics{Boolean}:
        A Boolean that controls compression of vector and text portions of the
        output file. Image compression is defined separately. The default value
        is True.


        image_compression{String}:
        A string that specifies the compression scheme used to compress image or
        raster data in the output file. The default value is ADAPTIVE.

        * DEFLATE: A lossless data compression.

        * NONE: Compression is not applied.

        * RLE: Run-length encoded compression.

        * JPEG: A lossy data compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.

        * ADAPTIVE: Automatically selects the best compression type for each
        image on the page.   JPEG will be used for large images with many unique
        colors.  DEFLATE will be used for all other images.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in the export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        layers_attributes{String}:
        A string that specifies whether the PDF layer and PDF object data
        (attributes) will be included in the export file. The default value is
        LAYERS_ONLY.

        * LAYERS_ONLY: Export PDF layers only

        * LAYERS_AND_ATTRIBUTES: Export PDF layers and feature attributes

        * NONE: None


        georef_info{Boolean}:
        A Boolean that enables the export of coordinate system information for
        each data frame into the output PDF file. The default value is True.


        jpeg_compression_quality{Integer}:
        A number that controls compression quality value when image_compression
        is set to ADAPTIVE or JPEG. The valid range is 1 through 100.    A
        jpeg_compression_quality of 100 provides the best quality images but
        creates large export files.   The recommended range is between 70 and
        90. The default value is 80.


        clip_to_elements{Boolean}:
        If set to True, the layout is clipped to the smallest bounding box that
        includes all layout elements. The default value is False.


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.


        pdf_accessibility{Boolean}:
        Output a tagged PDF file where text can be read by screen readers or
        other assistive technology.  A tagged PDF file can include alt text—a
        text
        description of a graphic element that a screen reader uses to
        describe the element—for map frames, pictures, and chart frames.
        Alt text is added in the
        Element Pane for each element. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, resolution, image_quality, compress_vector_graphics, image_compression, embed_fonts, layers_attributes, georef_info, jpeg_compression_quality, clip_to_elements, output_as_image, embed_color_profile, pdf_accessibility), True)))

    @constants.maskargs
    def exportToPNG(self, out_png, resolution=96, color_mode='32-BIT_WITH_ALPHA', transparent_background=False, embed_color_profile=True, clip_to_elements=False):
        """Layout.exportToPNG(out_png, {resolution}, {color_mode},
        {transparent_background}, {embed_color_profile}, {clip_to_elements})


        Exports the Layout to a Portable Network Graphics (PNG) format file.


        out_png(String):
        A string that represents the path and file name of the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 32-BIT_WITH_ALPHA.

        * 32-BIT_WITH_ALPHA: 32-bit with alpha

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 24-BIT_TRUE_COLOR: 24-bit true color


        transparent_background{Boolean}:
        If set to True, the white page background is set to transparent. The
        default value is False.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.


        clip_to_elements{Boolean}:
        If set to True, the layout is clipped to the smallest bounding box that
        includes all layout elements. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToPNG(*gp_fixargs((out_png, resolution, False, color_mode, transparent_background, embed_color_profile, clip_to_elements), True)))

    @constants.maskargs
    def exportToSVG(self, out_svg, resolution=96, compress_to_svgz=False, image_quality='BEST', embed_fonts=True, output_as_image=False, clip_to_elements=False):
        """Layout.exportToSVG(out_svg, {resolution}, {compress_to_svgz},
        {image_quality}, {embed_fonts}, {output_as_image}, {clip_to_elements})


        Exports the Layout to the Scalable Vector Graphics format (SVG).


        out_svg(String):
        A string that represents the path and file name for the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        compress_to_svgz{Boolean}:
        If set to True, the output is compressed. The default value is False.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2.

        * NORMAL: An output image quality resample ratio of 3.

        * FASTEST: An output image quality resample ratio of 5.

        * BEST: An output image quality resample ratio of 1.

        * FASTER: An output image quality resample ratio of 4.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in the export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.


        clip_to_elements{Boolean}:
        If set to True, the layout is clipped to the smallest bounding box that
        includes all layout elements. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToSVG(*gp_fixargs((out_svg, resolution, compress_to_svgz, image_quality, embed_fonts, output_as_image, clip_to_elements), True)))

    @constants.maskargs
    def exportToTGA(self, out_tga, resolution=96, color_mode='24-BIT_TRUE_COLOR', transparent_background=False, clip_to_elements=False):
        """Layout.exportToTGA(out_tga, {resolution}, {color_mode},
        {transparent_background}, {clip_to_elements})


        Exports the Layout to the Truevision Graphics Adapter format (TGA).


        out_tga(String):
        A string that represents the path and file name for the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 32-BIT_WITH_ALPHA.

        * 32-BIT_WITH_ALPHA: 32-bit with alpha

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 24-BIT_TRUE_COLOR: 24-bit true color


        transparent_background{Boolean}:
        If set to True, the white page background is set to transparent. The
        default value is False.


        clip_to_elements{Boolean}:
        If set to True, the layout is clipped to the smallest bounding box that
        includes all layout elements. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToTGA(*gp_fixargs((out_tga, resolution, color_mode, transparent_background, clip_to_elements), True)))

    @constants.maskargs
    def exportToTIFF(self, out_tif, resolution=96, color_mode='24-BIT_TRUE_COLOR', tiff_compression='LZW',
                     jpeg_compression_quality=80, transparent_background=False, embed_color_profile=True, clip_to_elements=False,
                     world_file=False, geoTIFF_tags=False, georef_mapframe=None):
        """Layout.exportToTIFF(out_tif, {resolution}, {color_mode},
        {tiff_compression}, {jpeg_compression_quality},
        {transparent_background}, {embed_color_profile}, {clip_to_elements},
        {world_file}, {geoTIFF_tags}, {georef_mapframe})


        Exports the Layout to a Tagged Image File Format (TIFF) file.


        out_tif(String):
        A string that represents the path and file name of the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        color_mode{String}:
        This value specifies the number of bits used to describe color. The
        available options are dependent on the specified Color Model set in the
        layout's Color Management properties. The default value is
        24-BIT_TRUE_COLOR.

        * 32-BIT_WITH_ALPHA: 32-bit with alpha. Available only to RGB.

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette. Available to RGB and
        CMYK.

        * 40-BIT_CMYK_WITH_ALPHA: 40-bit CMYK with alpha. Available only to
        CMYK.

        * 24-BIT_TRUE_COLOR: 24-bit true color. Available only to RGB.

        * 32-BIT_CMYK_TRUE_COLOR: 32-bit CMYK true color. Available only to
        CMYK.

        * 8-BIT_GRAYSCALE: 8-bit grayscale. Available to RGB and CMYK.


        tiff_compression{String}:
        This value represents a compression scheme. The default value is LZW.

        * DEFLATE: A lossless data compression.

        * NONE: Compression is not applied.

        * JPEG: JPEG compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.

        * PACK_BITS: Pack bits compression.


        jpeg_compression_quality{Integer}:
        This value (0–100) controls the amount of compression applied to the
        output image. With a JPEG image, quality is adversely affected the more
        compression is applied. A higher-quality (highest = 100) setting will
        produce sharper images and larger file sizes. A lower-quality setting
        will produce more image artifacts and smaller files. The default value
        is 80.


        transparent_background{Boolean}:
        If set to True, the white page background is set to transparent. The
        default value is False.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.


        clip_to_elements{Boolean}:
        If set to True, the layout is clipped to the smallest bounding box that
        includes all layout elements. The default value is False.


        world_file{Boolean}:
        If set to True and a valid georef_mapframe is
        set, a world file will be generated based on the map frame's
        coordinate system. The default value is False.


        geoTIFF_tags{Boolean}:
        If set to True and a valid georef_mapframe is set, geoTIFF tags will be
        embedded in the resulting image based on the map frame's coordinate
        system. The default value is False.


        georef_mapframe{MapFrame}:
        The MapFrame used to control the coordinate system when geoTIFF_tags are
        set to True. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToTIFF(*gp_fixargs((out_tif, resolution, color_mode, tiff_compression,
                                              jpeg_compression_quality, transparent_background, embed_color_profile, clip_to_elements,
                                              world_file, geoTIFF_tags, georef_mapframe), True)))

    @constants.maskargs
    def listElements(self, element_type=None, wildcard=None):
        """Layout.listElements({element_type}, {wildcard})


        Returns a Python list of page layout elements  that exist on  a Layout
        object.


        element_type{String}:
        A string that represents the element type that will be used to filter
        the returned list of elements. The default value is None.

        * MAPFRAME_ELEMENT: Filter for MapFrame objects.

        * MAPSURROUND_ELEMENT: Filter for MapsurroundElement objects.

        * GRAPHIC_ELEMENT: Filter for GraphicElement objects.

        * LEGEND_ELEMENT: Filter for LegendElement objects.

        * PICTURE_ELEMENT: Filter for PictureElement objects.

        * TEXT_ELEMENT: Filter for TextElement objects.


        wildcard{String}:
        A wildcard is based on the element name and is not case sensitive.  A
        combination of asterisks (*) and characters can be used to help limit
        the results. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listElements(*gp_fixargs((element_type, wildcard), True)))

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isLayoutSame(*gp_fixargs((other,), True)))

    @constants.maskargs
    def getDefinition(self, cim_version):
        """Layout.getDefinition(cim_version)


        Gets a layout's CIM definition.


        cim_version(String):
        A string that represents the major version of the CIM.
        """
        from .cim.cimloader import GetJSONTypeOBJ
        import json
        return GetJSONTypeOBJ(json.loads(convertArcObjectToPythonObject(self._arc_object.GetCimJSONString(*gp_fixargs((cim_version), True)))))

    @constants.maskargs
    def setDefinition(self, definition_object):
        """Layout.setDefinition(definition_object)


        Sets a layout's CIM definition.


        definition_object(Object):
        A modified CIM definition object originally retrieved using
        getDefinition.
        """
        from .cim.cimloader import  CimJsonEncoder
        import json
        json_data = json.dumps(definition_object, cls=CimJsonEncoder)
        return convertArcObjectToPythonObject(self._arc_object.SetCimJSONString(json_data))

    def openView(self):
        """Layout.openView()


        Opens and activates a new layout view pane in the application.
        """
        return convertArcObjectToPythonObject(self._arc_object.openView(*gp_fixargs((), True)))

class LegendElement(_ObjectWithoutInitCall):
    """The LegendElement object provides access to properties that enable its positioning
       and resizing on the page layout as well as modifying its title. It also provides
       access to individual LegendItems."""
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementWidth = passthrough_attr('elementWidth')
    locked = passthrough_attr('locked')
    name = passthrough_attr('name')
    mapFrame = passthrough_attr('mapFrame')
    title = passthrough_attr('title')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
    elementRotation = passthrough_attr('elementRotation')
    showTitle = passthrough_attr('showTitle')
    syncNewLayer = passthrough_attr('syncNewLayer')
    syncLayerOrder = passthrough_attr('syncLayerOrder')
    syncLayerVisibility = passthrough_attr('syncLayerVisibility')
    syncReferenceScale = passthrough_attr('syncReferenceScale')
    columnCount = passthrough_attr('columnCount')
    fittingStrategy = passthrough_attr('fittingStrategy')
    items = passthrough_attr('items')

    def removeItem(self, remove_item):
        """LegendElement.removeItem(remove_item)


        Allows you to remove a legend item from a legend.


        remove_item(LegendItem):
        A reference to a LegendItem object representing the item to be removed.
        """
        return convertArcObjectToPythonObject(self._arc_object.removeItem(*gp_fixargs((remove_item,), True)))

    @constants.maskargs
    def addItem(self, layer, add_position='TOP'):
        """LegendElement.addItem(layer, {add_position})


        Allows you to add a Layer to a legend using basic placement options.


        layer(Layer):
        A reference to a Layer object representing the layer to be added to a
        legend as a LegendItem.


        add_position{String}:
        A constant that determines the placement of the added layer within the
        legend. The default value is TOP.

        * TOP: Places the layer or layers at the top of the TOC layer stack.

        * BOTTOM: Places the layer or layers at the bottom of the TOC layer
        stack.
        """
        return convertArcObjectToPythonObject(self._arc_object.addItem(*gp_fixargs((layer, add_position), True)))

    @constants.maskargs
    def moveItem(self, reference_item, move_item, move_position='BEFORE'):
        """LegendElement.moveItem(reference_item, move_item, {move_position})


        Allows you to move a legend item to  a specific location within a
        legend.


        reference_item(LegendItem):
        A LegendItem object representing an existing legend item that determines
        the relative location where the  move_item will be moved.


        move_item(Layer):
        A reference to a LegendItem object representing the layer to be moved.


        move_position{String}:
        A constant that determines the placement of the moved layer relative to
        the reference layer. The default value is BEFORE.

        * AFTER: Moves the  legend item after or below the reference_item.

        * BEFORE: Moves the legend item before or above the reference_item.
        """
        return convertArcObjectToPythonObject(self._arc_object.moveItem(*gp_fixargs((reference_item, move_item, move_position), True)))

class LegendItem(_ObjectWithoutInitCall):
    """LegendItem provides access to legend item level information in a LegendElement."""
    arrangement = passthrough_attr('arrangement')
    patchHeight = passthrough_attr('patchHeight')
    patchWidth = passthrough_attr('patchWidth')
    showFeatureCount = passthrough_attr('showFeatureCount')
    showVisibleFeatures = passthrough_attr('showVisibleFeatures')
    visible = passthrough_attr('visible')
    type = passthrough_attr('type')
    name = passthrough_attr('name')
    column = passthrough_attr('column')

class Report(_ObjectWithoutInitCall):
    """The Report object references a report in an ArcGIS Pro
       project ( .aprx ).  It provides access to common properties like dataReference,
       definitionQuery, and the export method."""
    name = passthrough_attr('name')
    referenceDataSource = passthrough_attr('referenceDataSource')
    definitionQuery = passthrough_attr('definitionQuery')
    metadata = passthrough_attr('metadata')

    def setReferenceDataSource(self, data_source):
        """Report.setReferenceDataSource(data_source)


        Sets a report's reference data source.


        data_source(Object):
        The data reference that powers the report.  This parameter can be a
        Layer object, a Table object, or a string that represents the path to an
        external data source. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.setReferenceDataSource(*gp_fixargs((data_source,), True)))

    def exportToPDF(self, out_pdf, page_range_type='ALL', page_range='', starting_page_number=1, total_page_number=None, resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, jpeg_compression_quality=80):
        """Report.exportToPDF(out_pdf, {page_range_type}, {page_range},
        {starting_page_number}, {total_page_number}, {resolution},
        {image_quality}, {compress_vector_graphics}, {image_compression},
        {embed_fonts}, {jpeg_compression_quality})


        Exports a report to a Portable Document Format (PDF) file.


        out_pdf(String):
        A string that represents the path and file name of the output export
        file.


        page_range_type{String}:
        A string that defines the type of page range to export. The default is
        ALL. The default value is ALL.

        * EVEN: Export the even numbered pages of the report.

        * LAST: Export the last page of the report.

        * ALL: Export all pages of the report.

        * ODD: Export the odd numbered pages of the report.

        * RANGE: Export the pages listed in the page_range parameter .


        page_range{String}:
        A string that identifies the pages to be exported if the RANGE option in
        the page_range_type parameter is used (for example, 1, 3, 5-12).   If
        any other page_range_type value is used, the page_range value will be
        ignored.


        starting_page_number{Integer}:
        Applies an offset to the page numbering to add additional pages to the
        beginning of the report.  The default offset is 1. The default value is
        1.


        total_page_number{Integer}:
        The total number of pages to label, for example, when your report
        displays X of Y pages.  This is useful when you want to combine multiple
        reports into one.  The default is -1, which means there is no override.
        The default value is None.


        resolution{Integer}:
        An integer that defines the resolution of the export file in dots per
        inch (dpi). The default value is 96.


        image_quality{String}:
        A string that defines output image quality. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2

        * NORMAL: An output image quality resample ratio of 3

        * FASTEST: An output image quality resample ratio of 5

        * BEST: An output image quality resample ratio of 1

        * FASTER: An output image quality resample ratio of 4


        compress_vector_graphics{Boolean}:
        A Boolean that controls compression of vector and text portions of the
        output file. Image compression is defined separately. The default value
        is True.


        image_compression{String}:
        A string that defines the compression scheme used to compress image or
        raster data in the output file. The default value is ADAPTIVE.

        * NONE: Compression is not applied

        * RLE: Run-length encoded compression

        * JPEG: A lossy data compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression

        * DEFLATE: A lossless data compression

        * ADAPTIVE: Automatically selects the best compression type for each
        image on the page.   JPEG will be used for large images with many unique
        colors.  DEFLATE will be used for all other images.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in an export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        jpeg_compression_quality{Integer}:
        A number that controls compression quality value when image_compression
        is set to ADAPTIVE or JPEG. The valid range is 1 through 100.    A
        jpeg_compression_quality of 100 provides the best quality images but
        creates large export files.   The recommended range is 70 through 90.
        The default value is 80.
        """

        @constants.maskargs
        def maskArgsWrapper(out_pdf, report_page_range_type, page_range, starting_page_number,
                            total_page_number, resolution, image_quality, compress_vector_graphics,
                            image_compression, embed_fonts, jpeg_compression_quality):
            """Use this method to convert externally exposed page_range_type kwargs to the interal masked arg report_page_range_type"""
            return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, report_page_range_type, page_range,
                                                                                            starting_page_number, total_page_number, resolution,
                                                                                            image_quality, compress_vector_graphics, image_compression,
                                                                                            embed_fonts, jpeg_compression_quality), True)))

        try:
            return maskArgsWrapper(out_pdf, page_range_type, page_range,
                                     starting_page_number, total_page_number,
                                     resolution, image_quality, compress_vector_graphics,
                                     image_compression, embed_fonts, jpeg_compression_quality)
        except ValueError as e:
            message = str(e)
            if 'report_page_range_type' in message:
                cleanErr = ValueError(message.replace('report_page_range_type', 'page_range_type'))
                raise cleanErr from cleanErr
            else:
                raise e

    def listSections(self, wildcard=None):
        """Report.listSections({wildcard})


        Returns a Python list of ReportSection and ReportLayoutSection objects
        in a report.


        wildcard{String}:
        A wildcard is based on the section name and is not case sensitive.  A
        combination of asterisks (*) and characters can be used to help
        limit the resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listSections(*gp_fixargs((wildcard,), True)))

    def openView(self):
        """Report.openView()


        Opens and activates a new report view pane in the application.
        """
        return convertArcObjectToPythonObject(self._arc_object.openView(*gp_fixargs((), True)))

    @constants.maskargs
    def getDefinition(self, cim_version):
        """Report.getDefinition(cim_version)


        Gets a report's CIM definition.


        cim_version(String):
        A string that represents the major version of the CIM.
        """
        from .cim.cimloader import GetJSONTypeOBJ
        import json
        return GetJSONTypeOBJ(json.loads(convertArcObjectToPythonObject(self._arc_object.GetCimJSONString(*gp_fixargs((cim_version,), True)))))

    @constants.maskargs
    def setDefinition(self, definition_object):
        """Report.setDefinition(definition_object)


        Sets a report's CIM definition.


        definition_object(Object):
        A modified CIM definition object originally retrieved using
        getDefinition.
        """
        from .cim.cimloader import  CimJsonEncoder
        import json
        json_data = json.dumps(definition_object, cls=CimJsonEncoder)
        return convertArcObjectToPythonObject(self._arc_object.SetCimJSONString(json_data))

class ReportSection(_ObjectWithoutInitCall):
    """The ReportSection object references a reportSection in a Report.
       It provides access to common properties like dataReference and
       definitionQuery."""
    name = passthrough_attr('name')
    referenceDataSource = passthrough_attr('referenceDataSource')
    definitionQuery = passthrough_attr('definitionQuery')
    visible = passthrough_attr('visible')
    type = passthrough_attr('type')

    def setReferenceDataSource(self, data_source):
        """ReportSection.setReferenceDataSource(data_source)


        Sets a report section's reference data source.


        data_source(Object):
        The data reference for the report section.  This parameter can be a
        Layer object, a Table object, or a string that represents the path to an
        external data source. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.setReferenceDataSource(*gp_fixargs((data_source,), True)))

    def setRelatedReportSource(self, related_report_data_source, related_report_section_name, relate_or_relationship_class_name):
        """ReportSection.setRelatedReportSource(related_report_data_source,
        related_report_section_name, relate_or_relationship_class_name)


        Sets a related report's data source.


        related_report_data_source(Object):
        The data source for the new related report.  This parameter can be a
        Layer object, a Table object, or a string that represents the path to an
        external data source. The default value is None.


        related_report_section_name(String):
        The name of the related report. The default value is None.


        relate_or_relationship_class_name(String):
        The name of the new relate or relationship class. The default value is
        None.
        """
        return convertArcObjectToPythonObject(self._arc_object.setRelatedReportSource(*gp_fixargs((related_report_data_source, related_report_section_name, relate_or_relationship_class_name), True)))

class ReportLayoutSection(_ObjectWithoutInitCall):
    """The ReportLayoutSection object references a reportLayoutSection in a Report.
       It provides access to common properties like name and visibility."""
    name = passthrough_attr('name')
    visible = passthrough_attr('visible')
    type = passthrough_attr('type')
    URI = passthrough_attr('URI')

class Map(_ObjectWithoutInitCall):
    """The Map is the primary object for referencing and managing layers and
       tables within an ArcGIS Pro project."""
    defaultCamera = passthrough_attr('defaultCamera')
    defaultView = passthrough_attr('defaultView', True)
    mapType = passthrough_attr('mapType')
    name = passthrough_attr('name')
    referenceScale = passthrough_attr('referenceScale')
    mapUnits = passthrough_attr('mapUnits')
    metadata = passthrough_attr('metadata')
    spatialReference = passthrough_attr('spatialReference')
    URI = passthrough_attr('URI')
    transformations = passthrough_attr('transformations')

    @constants.maskargs
    def addLayer(self, add_layer_or_layerfile, add_position='AUTO_ARRANGE'):
        """Map.addLayer(add_layer_or_layerfile, {add_position})


        Provides the ability to add a Layer or LayerFile to a map within a
        project (.aprx) using basic placement options.


        add_layer_or_layerfile(Layer):
        A reference to a Layer or LayerFile object representing the layer or
        layers  to be added.


        add_position{String}:
        A constant that determines the placement of the added layer or layers
        in a map. The default value is AUTO_ARRANGE.

        * TOP: Places the layer or layers at the top of the TOC layer stack.

        * AUTO_ARRANGE: Automatically places the layer or layers based on its
        layer weight rules and geometry.

        * BOTTOM: Places the layer or layers at the bottom of the TOC layer
        stack.
        """
        return convertArcObjectToPythonObject(self._arc_object.addLayer(*gp_fixargs((add_layer_or_layerfile, add_position), True)))

    @constants.maskargs
    def addLayerToGroup(self, target_group_layer, add_layer_or_layerfile, add_position='AUTO_ARRANGE'):
        """Map.addLayerToGroup(target_group_layer, add_layer_or_layerfile,
        {add_position})


        Provides the ability to add a Layer or the contents of a LayerFile to an
        existing group layer in a map within a project (.aprx) using basic
        placement options.


        target_group_layer(Layer):
        A reference to an existing group Layer object.


        add_layer_or_layerfile(Layer):
        A reference to a Layer or LayerFile object representing the layer or
        layers  to be added.


        add_position{String}:
        A constant that determines the placement of the added layer or layers in
        the target_group_layer. The default value is AUTO_ARRANGE.

        * TOP: Places the layer at the top of the TOC layer stack.

        * AUTO_ARRANGE: Automatically places the layer based on its layer weight
        rules and geometry.

        * BOTTOM: Places the layer at the bottom of the TOC layer stack.
        """
        return convertArcObjectToPythonObject(self._arc_object.addLayerToGroup(*gp_fixargs((target_group_layer, add_layer_or_layerfile, add_position), True)))

    def addTable(self, add_table):
        """Map.addTable(add_table)


        Provides the ability to add a Table  to a map within a project (.aprx).


        add_table(Table):
        A reference to a Table object representing the table  to be added.
        """
        return convertArcObjectToPythonObject(self._arc_object.addTable(*gp_fixargs((add_table,), True)))

    def addTableToGroup(self, target_group_layer, add_table):
        """Map.addTableToGroup(target_group_layer, add_table)


        Provides the ability to add a Table to an existing group layer in a map
        within a project (.aprx).


        target_group_layer(Layer):
        A reference to an existing group layer.


        add_table(Table):
        A reference to a Table object.
        """
        return convertArcObjectToPythonObject(self._arc_object.addTableToGroup(*gp_fixargs((target_group_layer, add_table), True)))

    def clearSelection(self):
        """Map.clearSelection()


        Clears the selection for all layers and tables in a map.
        """
        return convertArcObjectToPythonObject(self._arc_object.clearSelection(*gp_fixargs((), True)))

    @constants.maskargs
    def insertLayer(self, reference_layer, insert_layer_or_layerfile, insert_position='BEFORE'):
        """Map.insertLayer(reference_layer, insert_layer_or_layerfile,
        {insert_position})


        Provides the ability to add a Layer or LayerFile to a map within a
        project (.aprx) by specifying  a specific location.


        reference_layer(Layer):
        A Layer object representing an existing layer that determines the
        location where the new layer will be inserted.


        insert_layer_or_layerfile(Layer):
        A reference to a Layer or LayerFile object representing the layer or
        layers  to be added.


        insert_position{String}:
        A constant that determines the placement of the added layer or layers
        relative to the reference_layer. The default value is BEFORE.

        * AFTER: Inserts the new layer after or below the reference layer.

        * BEFORE: Inserts the new layer before or above the reference layer.
        """
        return convertArcObjectToPythonObject(self._arc_object.insertLayer(*gp_fixargs((reference_layer, insert_layer_or_layerfile, insert_position), True)))

    def listBookmarks(self, wildcard=None):
        """Map.listBookmarks({wildcard})


        Returns a Python list of bookmark objects in a Map.


        wildcard{String}:
        A wildcard is based on the bookmark name and is not case sensitive. A
        combination of asterisks (*) and characters can be used to help
        limit the resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listBookmarks(*gp_fixargs((wildcard,), True)))

    def listBrokenDataSources(self):
        """Map.listBrokenDataSources()


        Returns a Python list of Layer or Table objects that have broken
        connections to their original source data within a map.
        """
        return convertArcObjectToPythonObject(self._arc_object.listBrokenDataSources(*gp_fixargs((), True)))

    def listLayers(self, wildcard=None):
        """Map.listLayers({wildcard})


        Returns a Python list of Layer objects that exist within a map.


        wildcard{String}:
        A wildcard is based on the layer name and is not case sensitive. A
        combination of asterisks (*) and characters can be used to help
        limit the resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listLayers(*gp_fixargs((wildcard,), True)))

    def listTables(self, wildcard=None):
        """Map.listTables({wildcard})


        Returns a Python list of Table objects that exist within a map.


        wildcard{String}:
        A wildcard is based on the layer name and is not case sensitive.  A
        combination of asterisks (*) and characters can be used to help limit
        the resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listTables(*gp_fixargs((wildcard,), True)))

    def addBasemap(self, basemap_name):
        """Map.addBasemap(basemap_name)


        addBasemap provides the ability to add or replace a basemap layer within
        a map.


        basemap_name(String):
        The name of the basemap as it appears in the basemap gallery.
        """
        return convertArcObjectToPythonObject(self._arc_object.addBasemap(*gp_fixargs((basemap_name,), True)))

    @constants.maskargs
    def addDataFromPath(self, data_path, web_service_type="AUTOMATIC", custom_parameters=None):
        """Map.addDataFromPath(data_path, {web_service_type}, {custom_parameters})


        addDataFromPath allows you to add a Layer  to a map in a project (.aprx)
        by providing a local path or URL.


        data_path(String):
        A string that represents a local path or URL. The default value is None.


        web_service_type{String}:
        A string that represents the type of web service connection. When you
        are working with a service URL that is hosted on a third-party server
        and the URL is not deterministic, you must specify the service type from
        the list to add the data.  The default value of AUTOMATIC will not work
        if the custom_parameters dictionary is provided. The default value is
        AUTOMATIC.

        * WMS: A WMS OGC web service

        * KML: KML

        * AUTOMATIC: Attempt to automatically match the correct service based on
        the provided URL

        * ARCGIS_SERVER_WEB: An ArcGIS Server web service

        * VECTOR_TILE: A vector tile service


        custom_parameters{Dictionary}:
        A Python dictionary of custom connection parameters.  The KML
        data_service_type does not support custom properties. The default value
        is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.addDataFromPath(*gp_fixargs((data_path, web_service_type, custom_parameters,), True)))

    @constants.maskargs
    def moveLayer(self, reference_layer, move_layer, insert_position='BEFORE'):
        """Map.moveLayer(reference_layer, move_layer, {insert_position})


        Provides the ability to move a layer or group layer in a map to  a
        specific location in the layer stack.


        reference_layer(Layer):
        A Layer  object representing an existing layer that determines the
        location where the new layer will be moved.


        move_layer(Layer):
        A reference to a Layer object representing the layer to be moved.


        insert_position{String}:
        A constant that determines the placement of the moved layer relative to
        the reference layer. The default value is BEFORE.

        * AFTER: Moves the  layer after or below the reference layer.

        * BEFORE: Moves the layer before or above the reference layer.
        """
        return convertArcObjectToPythonObject(self._arc_object.moveLayer(*gp_fixargs((reference_layer, move_layer, insert_position), True)))

    def removeLayer(self, remove_layer):
        """Map.removeLayer(remove_layer)


        Provides the ability to remove a layer from a map in a project.


        remove_layer(Layer):
        A reference to a Layer object representing the layer to be removed.
        """
        return convertArcObjectToPythonObject(self._arc_object.removeLayer(*gp_fixargs((remove_layer,), True)))

    def removeTable(self, remove_table):
        """Map.removeTable(remove_table)


        Provides the ability to remove a table from a map in a project.


        remove_table(Table):
        A reference to a Table object representing the layer to be removed.
        """
        return convertArcObjectToPythonObject(self._arc_object.removeTable(*gp_fixargs((remove_table,), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True, ignore_case=False):
        """Map.updateConnectionProperties(current_connection_info,
        new_connection_info, {auto_update_joins_and_relates}, {validate},
        {ignore_case})


        The updateConnectionProperties method replaces connection properties
        using a dictionary or a path to a workspace.


        current_connection_info(String):
        A string that represents the workspace path or a Python dictionary that
        contains connection properties to the source you want to update. If an
        empty string or None is used in current_connection_info, all connection
        properties will be replaced with the new_workspace_info, depending on
        the value of the validate parameter.


        new_connection_info(String):
        A string that represents the workspace path or a Python dictionary that
        contains connection properties with the new source information.


        auto_update_joins_and_relates{Boolean}:
        If  set to True, the updateConnectionProperties method will also update
        the connections for associated joins or relates. The default value is
        True.


        validate{Boolean}:
        If  set to True, the connection properties will only be updated if the
        new_connection_info value is a valid connection.  If it is not valid,
        the connection will not be replaced.   If set to False, the method will
        set all connections to match the new_connection_info value, regardless
        of a valid match.  In this case, if a match does not exist, the data
        sources would be broken. The default value is True.


        ignore_case{Boolean}:
        Determines whether searches will be case sensitive. By default, queries
        are case sensitive. To perform queries that are not case sensitive, set
        ignore_case to True. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate, ignore_case), True)))

    def getWebLayerSharingDraft(self, server_type, service_type, service_name, layers_and_tables=None):
        """Map.getWebLayerSharingDraft(server_type, service_type, service_name,
        {layers_and_tables})


        Creates a sharing draft from a map that can be configured and shared to
        ArcGIS Enterprise or ArcGIS Online.


        server_type(String):
        A string representing the server type.
        The following server types are supported:
        The getWebLayerSharingDraft function does not support publishing  map
        services to ArcGIS Server. Instead, use the
        arcpy.sharing.CreateSharingDraft function.

        * FEDERATED_SERVER: Supports publishing a map image layer to an ArcGIS
        Enterprise portal federated server. Use this option when specifying
        MAP_IMAGE  in the service_type parameter.

        * HOSTING_SERVER: Supports publishing either a web feature layer or a
        web tile layer to ArcGIS Enterprise or ArcGIS Online. Use this option
        when specifying FEATURE or TILE  in the service_type parameter.


        service_type(String):
        A string representing the service type. The following service types are
        supported:

        * TILE: Creates a TileSharingDraft for a web tile layer

        * MAP_IMAGE: Creates a MapImageSharingDraft for a map image layer

        * FEATURE: Creates a FeatureSharingDraft for a web feature layer


        service_name(String):
        A string that represents the name of the service. This is the name
        people will see and use to identify the service. The name can contain
        alphanumeric characters, spaces, and underscores. No special characters
        are allowed. The name cannot be more than 120 characters in length.


        layers_and_tables{List}:
        A list of layers and tables from the map. If left blank, the entire map
        will be published. This parameter allows you to choose a subset of
        layers and tables from the map to publish. The layers and tables must be
        from the same map that is being published.If you specify a layer or
        table that participates in a relationship class when publishing a web
        feature layer or a map image layer, all layers or tables involved in the
        relationship class will be published.
        """
        validation_map = {
            "FEDERATED_SERVER": ["MAP_IMAGE"],
            "MY_HOSTED_SERVICES": ["TILE", "FEATURE"],
            "HOSTING_SERVER": ["TILE", "FEATURE"],
            }
        if service_type in validation_map[server_type]:
          if service_type == "TILE":
            from arcpy.sharing import TileSharingDraft
            tileSharingObject = TileSharingDraft()
            tileSharingObject.server_type = server_type
            tileSharingObject.service_type = service_type
            convertArcObjectToPythonObject(self._arc_object.getWebLayerSharingDraft(tileSharingObject, *gp_fixargs((server_type, service_type, service_name, layers_and_tables), True)))
            return tileSharingObject
          if service_type == "FEATURE":
            from arcpy.sharing import FeatureSharingDraft
            featureSharingObject = FeatureSharingDraft()
            featureSharingObject.serverType = server_type
            featureSharingObject.serviceType = service_type
            convertArcObjectToPythonObject(self._arc_object.getWebLayerSharingDraft(featureSharingObject, *gp_fixargs((server_type, service_type, service_name, layers_and_tables), True)))
            return featureSharingObject
          if service_type == "MAP_IMAGE":
            from arcpy.sharing import MapImageSharingDraft
            mapImageObject = MapImageSharingDraft()
            mapImageObject.serverType = server_type
            mapImageObject.serviceType = service_type
            convertArcObjectToPythonObject(self._arc_object.getWebLayerSharingDraft(mapImageObject, *gp_fixargs(( server_type, service_type, service_name, layers_and_tables), True, pass_arc_object=True)))
            return mapImageObject
        raise ValueError("Incompatible server_type: {} and service_type: {}".format(server_type, service_type))

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isMapSame(*gp_fixargs((other,), True)))

    @constants.maskargs
    def getDefinition(self, cim_version):
        """Map.getDefinition(cim_version)


        Gets a map's CIM definition.


        cim_version(String):
        A string that represents the major version of the CIM.
        """
        from .cim.cimloader import GetJSONTypeOBJ
        import json
        return GetJSONTypeOBJ(json.loads(convertArcObjectToPythonObject(self._arc_object.GetCimJSONString(*gp_fixargs((cim_version), True)))))

    @constants.maskargs
    def setDefinition(self, definition_object):
        """Map.setDefinition(definition_object)


        Sets a map's CIM definition.


        definition_object(Object):
        A modified CIM definition object originally retrieved using
        getDefinition.
        """
        from .cim.cimloader import  CimJsonEncoder
        import json
        json_data = json.dumps(definition_object, cls=CimJsonEncoder)
        return convertArcObjectToPythonObject(self._arc_object.SetCimJSONString(json_data))

    def exportToMAPX(self, out_mapx):
        """Map.exportToMAPX(out_mapx)


        Exports a Map  to a map file.


        out_mapx(String):
        A string used to save a Map to a map file (.mapx).
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToMAPX(*gp_fixargs((out_mapx,), True)))

    @constants.maskargs
    def createGroupLayer(self, name, group_layer=None):
        """Map.createGroupLayer(name, {group_layer})


        Allows you to create  a group layer in a map within a project (.aprx).


        name(String):
        A string that represents the name of the new group layer.


        group_layer{Layer}:
        A reference to an existing group layer into which  to insert the new
        group layer. Use this parameter to create nested group layers.
        """
        return convertArcObjectToPythonObject(self._arc_object.createGroupLayer(*gp_fixargs((name, group_layer,), True)))

    def openView(self):
        """Map.openView()


        Opens and activates a new map view pane in the application.
        """
        return convertArcObjectToPythonObject(self._arc_object.openView(*gp_fixargs((), True)))

    def updateTransformations(self, transformations):
        """Map.updateTransformations(transformations)


        The updateTransformations method replaces a map's transformations using
        a dictionary.


        transformations(Dictionary):
        The dictionary keys are defined below.

        * 2D: Horizontal transformations, if any exist

        * 3D: Vertical transformations, if any exist
        """
        return convertArcObjectToPythonObject(self._arc_object.updateTransformations(*gp_fixargs((transformations,), True)))


class MapFrame(_ObjectWithoutInitCall):
    """The MapFrame object is a page layout element that is used to display the
       contents of a map on a layout.      It also provides access to page size
       and positioning, basic navigation methods,  and export options."""
    camera = passthrough_attr('camera')
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementRotation = passthrough_attr('elementRotation')
    elementWidth = passthrough_attr('elementWidth')
    locked = passthrough_attr('locked')
    map = passthrough_attr('map')
    name = passthrough_attr('name')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
    time = passthrough_attr('time')

    @constants.maskargs
    def exportToBMP(self, out_bmp, resolution=96, world_file=False, bmp_color_mode='24-BIT_TRUE_COLOR', bmp_image_compression='NONE', embed_color_profile=True):
        """MapFrame.exportToBMP(out_bmp, {resolution}, {world_file},
        {bmp_color_mode}, {bmp_image_compression}, {embed_color_profile})


        Exports the MapFrame to a Microsoft Windows Bitmap (BMP) format file.


        out_bmp(String):
        A string that represents the path and file name of the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        world_file{Boolean}:
        If set to True, a georeferenced world file is created. The file contains
        pixel scale information and real-world coordinate information. The
        default value is False.


        bmp_color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 24-BIT_TRUE_COLOR.

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 24-BIT_TRUE_COLOR: 24-bit true color


        bmp_image_compression{String}:
        A string that specifies the compression scheme used to compress image or
        raster data in the output file.  This option only applies to 8-bit
        bmp_color_mode options. The default value is NONE.

        * RLE: Run-length encoded compression.

        * NONE: Compression is not applied.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToBMP(*gp_fixargs((out_bmp, resolution, world_file, bmp_color_mode, bmp_image_compression, embed_color_profile), True)))

    @constants.maskargs
    def exportToEMF(self, out_emf, resolution=96, image_quality='BEST', output_as_image=False):
        """MapFrame.exportToEMF(out_emf, {resolution}, {image_quality},
        {output_as_image})


        Exports the MapFrame to an Enhanced Metafile (EMF) format file.


        out_emf(String):
        A string that represents the system path and file name of the output
        export file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2

        * NORMAL: An output image quality resample ratio of 3

        * FASTEST: An output image quality resample ratio of 5

        * BEST: An output image quality resample ratio of 1

        * FASTER: An output image quality resample ratio of 4


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToEMF(*gp_fixargs((out_emf, resolution, image_quality, output_as_image), True)))

    @constants.maskargs
    def exportToEPS(self, out_eps, resolution=96, image_compression='DEFLATE', image_quality='BEST',
                   embed_fonts=True, output_as_image=False):
        """MapFrame.exportToEPS(out_eps, {resolution}, {image_compression},
        {image_quality}, {embed_fonts}, {output_as_image})


        Exports the MapFrame to an Encapsulated PostScript (EPS) format file.


        out_eps(String):
        A string that represents the system path and file name of the output
        export file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        image_compression{String}:
        A string that specifies the compression scheme used to compress image or
        raster data in the output file. The default value is DEFLATE.

        * RLE: Run-length encoded compression.

        * NONE: Compression is not applied.

        * DEFLATE: A lossless data compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2.

        * NORMAL: An output image quality resample ratio of 3.

        * FASTEST: An output image quality resample ratio of 5.

        * BEST: An output image quality resample ratio of 1.

        * FASTER: An output image quality resample ratio of 4.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in the export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToEPS(*gp_fixargs((out_eps, resolution, image_compression, image_quality, embed_fonts, output_as_image), True)))

    @constants.maskargs
    def exportToGIF(self, out_gif, resolution=96, world_file=False, gif_color_mode='8-BIT_ADAPTIVE_PALETTE'):
        """MapFrame.exportToGIF(out_gif, {resolution}, {world_file},
        {gif_color_mode})


        Exports the MapFrame to a Graphic Interchange Format (GIF) file.


        out_gif(String):
        A string that represents the system path and file name of the output
        export file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        world_file{Boolean}:
        If set to True, a georeferenced world file is created. The file contains
        pixel scale information and real-world coordinate information. The
        default value is False.


        gif_color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 8-BIT_PALETTE.

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 8-BIT_PALETTE: 8-bit adaptive palette
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToGIF(*gp_fixargs((out_gif, resolution, world_file, gif_color_mode), True)))

    @constants.maskargs
    def exportToJPEG(self, out_jpg, resolution=96, world_file=False, jpeg_color_mode='24-BIT_TRUE_COLOR', jpeg_quality=80, embed_color_profile=True):
        """MapFrame.exportToJPEG(out_jpg, {resolution}, {world_file},
        {jpeg_color_mode}, {jpeg_quality}, {embed_color_profile})


        Exports the MapFrame to the Joint Photographic Experts Group (JPEG)
        format.


        out_jpg(String):
        A string that represents the path and file name for the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        world_file{Boolean}:
        If set to True, a georeferenced world file is created. The file contains
        pixel scale information and real-world coordinate information.  If you
        export a 3D map frame, this parameter will be ignored regardless of the
        setting because world files are not applicable to 3D views. The default
        value is False.


        jpeg_color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 24-BIT_TRUE_COLOR.

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 24-BIT_TRUE_COLOR: 24-bit true color


        jpeg_quality{Integer}:
        This value (0–100) controls the amount of compression applied to the
        output image. For JPEG, image quality is adversely affected the more
        compression is applied. A higher quality (highest = 100) setting will
        produce sharper images and larger file sizes. A lower quality setting
        will produce more image artifacts and smaller files. The default value
        is 80.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToJPEG(*gp_fixargs((out_jpg, resolution, world_file, jpeg_color_mode, jpeg_quality, embed_color_profile), True)))

    @constants.maskargs
    def exportToPDF(self, out_pdf, resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, layers_attributes='LAYERS_ONLY', georef_info=True, jpeg_compression_quality=80, output_as_image=False, embed_color_profile=True):
        """MapFrame.exportToPDF(out_pdf, {resolution}, {image_quality},
        {compress_vector_graphics}, {image_compression}, {embed_fonts},
        {layers_attributes}, {georef_info}, {jpeg_compression_quality},
        {output_as_image}, {embed_color_profile})


        Exports the MapFrame  to a Portable Document Format (PDF) file.


        out_pdf(String):
        A string that represents the path and file name of the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 300.


        image_quality{String}:
        A string that defines the output image quality and the draw resolution
        of map layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2

        * NORMAL: An output image quality resample ratio of 3

        * FASTEST: An output image quality resample ratio of 5

        * BEST: An output image quality resample ratio of 1

        * FASTER: An output image quality resample ratio of 4


        compress_vector_graphics{Boolean}:
        A Boolean that controls the compression of vector and text portions of
        the output file. Image compression is defined separately. The default
        value is True.


        image_compression{String}:
        A string that defines the compression scheme used to compress image or
        raster data in the output file. The default value is ADAPTIVE.

        * DEFLATE: A lossless data compression.

        * NONE: Compression is not applied.

        * RLE: Run-length encoded compression.

        * JPEG: A lossy data compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.

        * ADAPTIVE: Automatically selects the best compression type for each
        image on the page.   JPEG will be used for large images with many unique
        colors.  DEFLATE will be used for all other images.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in the export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        layers_attributes{String}:
        A string that controls the inclusion of PDF layers and PDF object data
        (attributes) in the export file. The default value is LAYERS_ONLY.

        * LAYERS_ONLY: Export PDF layers only.

        * LAYERS_AND_ATTRIBUTES: Export PDF layers and feature attributes.

        * NONE: No setting is applied.


        georef_info{Boolean}:
        A Boolean that enables the export of coordinate system information for
        each data frame into the output PDF file. The default value is True.


        jpeg_compression_quality{Integer}:
        A number that controls the compression quality value when
        image_compression is set to ADAPTIVE or JPEG. The valid range is 1
        through 100.    A jpeg_compression_quality of 100 provides the best
        quality images but creates large export files.   The recommended range
        is 70 through 90. The default value is 80.


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, resolution, image_quality, compress_vector_graphics, image_compression, embed_fonts, layers_attributes, georef_info, jpeg_compression_quality, False, output_as_image, embed_color_profile), True)))

    @constants.maskargs
    def exportToPNG(self, out_png, resolution=96, world_file=False, color_mode='32-BIT_WITH_ALPHA', embed_color_profile=True):
        """MapFrame.exportToPNG(out_png, {resolution}, {world_file}, {color_mode},
        {embed_color_profile})


        Exports the MapFrame to Portable Network Graphics (PNG) format.


        out_png(String):
        A string that represents the path and file name for the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        world_file{Boolean}:
        If set to True, a georeferenced world file is created. The file contains
        pixel scale information and real-world coordinate information.  If you
        export a 3D map frame, this parameter will be ignored regardless of the
        setting because world files are not applicable to 3D views. The default
        value is False.


        color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 32-BIT_WITH_ALPHA.

        * 32-BIT_WITH_ALPHA: 32-bit with alpha

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 24-BIT_TRUE_COLOR: 24-bit true color


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToPNG(*gp_fixargs((out_png, resolution, world_file, color_mode, embed_color_profile), True)))

    @constants.maskargs
    def exportToSVG(self, out_svg, resolution=96, compress_to_svgz=False, image_quality='BEST', embed_fonts=True, output_as_image=False):
        """MapFrame.exportToSVG(out_svg, {resolution}, {compress_to_svgz},
        {image_quality}, {embed_fonts}, {output_as_image})


        Exports the MapFrame to a Scalable Vector Graphics (SVG) format file.


        out_svg(String):
        A string that represents the path and file name of the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        compress_to_svgz{Boolean}:
        If set to True, the output is compressed. The default value is False.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2.

        * NORMAL: An output image quality resample ratio of 3.

        * FASTEST: An output image quality resample ratio of 5.

        * BEST: An output image quality resample ratio of 1.

        * FASTER: An output image quality resample ratio of 4.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in the export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToSVG(*gp_fixargs((out_svg, resolution, compress_to_svgz,
            image_quality, embed_fonts, output_as_image), True)))

    @constants.maskargs
    def exportToTGA(self, out_tga, resolution=96, world_file=False, color_mode='24-BIT_TRUE_COLOR'):
        """MapFrame.exportToTGA(out_tga, {resolution}, {world_file}, {color_mode})


        Exports the MapFrame to a Truevision Graphics Adapter (TGA) format file.


        out_tga(String):
        A string that represents the path and file name of the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        world_file{Boolean}:
        If set to True, a georeferenced world file is created. The file contains
        pixel scale information and real-world coordinate information. The
        default value is False.


        color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 32-BIT_WITH_ALPHA.

        * 32-BIT_WITH_ALPHA: 32-bit with alpha

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 24-BIT_TRUE_COLOR: 24-bit true color
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToTGA(*gp_fixargs((out_tga, resolution, world_file, color_mode), True)))

    @constants.maskargs
    def exportToTIFF(self, out_tif, resolution=96, world_file=False, color_mode='24-BIT_TRUE_COLOR', tiff_compression='LZW', geoTIFF_tags=False,
                    jpeg_compression_quality=80, embed_color_profile=True):
        """MapFrame.exportToTIFF(out_tif, {resolution}, {world_file}, {color_mode},
        {tiff_compression}, {geoTIFF_tags}, {jpeg_compression_quality},
        {embed_color_profile})


        Exports the MapFrame to Tagged Image File Format (TIFF).


        out_tif(String):
        A string that represents the path and file name for the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        world_file{Boolean}:
        If set to True, a georeferenced world file is created. The file contains
        pixel scale information and real-world coordinate information.  If you
        export a 3D map frame, this parameter will be ignored regardless of the
        setting because world files are not applicable to 3D views. The default
        value is False.


        color_mode{String}:
        This value specifies the number of bits used to describe color. The
        available options are dependent on the specified Color Model set in the
        layout's Color Management properties. The default value is
        24-BIT_TRUE_COLOR.

        * 32-BIT_WITH_ALPHA: 32-bit with alpha. Available only to RGB.

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette. Available to RGB and
        CMYK.

        * 40-BIT_CMYK_WITH_ALPHA: 40-bit CMYK with alpha. Available only to
        CMYK.

        * 24-BIT_TRUE_COLOR: 24-bit true color. Available only to RGB.

        * 32-BIT_CMYK_TRUE_COLOR: 32-bit CMYK true color. Available only to
        CMYK.

        * 8-BIT_GRAYSCALE: 8-bit grayscale. Available to RGB and CMYK.


        tiff_compression{String}:
        This value represents a compression scheme. The default value is LZW.

        * DEFLATE: A lossless data compression.

        * NONE: Compression is not applied.

        * JPEG: JPEG compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.

        * PACK_BITS: Pack bits compression.


        geoTIFF_tags{Boolean}:
        If set to True, georeferencing tags are included in the structure of the
        TIFF export file. The tags contain pixel scale information and real-
        world coordinate information. These tags can be read by applications
        that support GeoTIFF format. The default value is False.


        jpeg_compression_quality{Integer}:
        This value (0–100) controls the amount of compression applied to the
        output image. With a JPEG image, quality is adversely affected the more
        compression is applied. A higher quality (highest = 100) setting will
        produce sharper images and larger file sizes. A lower quality setting
        will produce more image artifacts and smaller files. The default value
        is 80.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToTIFF(*gp_fixargs((out_tif, resolution, world_file, color_mode, tiff_compression, geoTIFF_tags,
                                              jpeg_compression_quality, embed_color_profile), True)))

    def getLayerExtent(self, layer, selection_only=True, symbolized_extent=True):
        """MapFrame.getLayerExtent(layer, {selection_only}, {symbolized_extent})


        Returns a layer's extent for all features or only the selected features
        in a layer.


        layer(Layer):
        A reference to a Layer object.


        selection_only{Boolean}:
        If True, it returns the extent for selected features; if False, it
        returns the extent for all features. The default value is True.


        symbolized_extent{Boolean}:
        A value of True will return the layer's symbolized extent; otherwise, it
        will return the geometric extent.  The symbolized extent takes into
        account the area the symbology covers so that it does not get cut off by
        the data frame's boundary. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.getLayerExtent(*gp_fixargs((layer, selection_only, symbolized_extent), True)))

    def panToExtent(self, extent):
        """MapFrame.panToExtent(extent)


        Pans and centers the MapFrame using a new Extent object without changing
        the map frame's scale.


        extent(Extent):
        A geoprocessing Extent object.
        """
        return convertArcObjectToPythonObject(self._arc_object.panToExtent(*gp_fixargs((extent,), True)))

    def zoomToAllLayers(self, selection_only=True, symbolized_extent=True):
        """MapFrame.zoomToAllLayers({selection_only}, {symbolized_extent})


        Modifies the MapFrame view to match the extent of all layers or selected
        layers in a map.


        selection_only{Boolean}:
        If True, it sets the extent based on the selected  features; if False,
        it sets the extent for all  features in a map. The default value is
        True.


        symbolized_extent{Boolean}:
        A value of True will return the layer's symbolized extent; otherwise, it
        will return the geometric extent.  The symbolized extent takes into
        account the area the symbology covers so that it does not get cut off by
        the map frame's boundary. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.zoomToAllLayers(*gp_fixargs((selection_only, symbolized_extent), True)))

    def zoomToBookmark(self, bookmark):
        """MapFrame.zoomToBookmark(bookmark)


        Modifies the MapFrame view to match the view information stored with a
        spatial bookmark.


        bookmark(Bookmark):
        A reference to a Bookmark object.
        """
        return convertArcObjectToPythonObject(self._arc_object.zoomToBookmark(*gp_fixargs((bookmark,), True)))

    @constants.maskargs
    def exportToAIX(self, out_aix, resolution=300, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', jpeg_compression_quality=80, embed_fonts=True, embed_color_profile=True):
        """MapFrame.exportToAIX(out_aix, {resolution}, {image_quality},
        {compress_vector_graphics}, {image_compression},
        {jpeg_compression_quality}, {embed_fonts}, {embed_color_profile})


        Exports the MapFrame  to Adobe Illustrator Exchange (AIX) format. AIX
        files can be used with the ArcGIS Maps for Adobe Creative Cloud
        extension or Adobe Illustrator.


        out_aix(String):
        A string that represents the path and file name for the output export
        file.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 300.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2

        * NORMAL: An output image quality resample ratio of 3

        * FASTEST: An output image quality resample ratio of 5

        * BEST: An output image quality resample ratio of 1

        * FASTER: An output image quality resample ratio of 4


        compress_vector_graphics{Boolean}:
        A Boolean that controls compression of vector and text portions of the
        output file. Image compression is defined separately. The default value
        is True.


        image_compression{String}:
        A string that specifies the compression scheme used to compress image or
        raster data in the output file. The default value is ADAPTIVE.

        * DEFLATE: A lossless data compression.

        * NONE: Compression is not applied.

        * RLE: Run-length encoded compression.

        * JPEG: A lossy data compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.

        * ADAPTIVE: Automatically selects the best compression type for each
        image on the page.   JPEG will be used for large images with many unique
        colors.  DEFLATE will be used for all other images.


        jpeg_compression_quality{Integer}:
        A number that controls compression quality value when image_compression
        is set to ADAPTIVE or JPEG. The valid range is 1 through 100.    A
        jpeg_compression_quality of 100 provides the best quality images but
        creates large export files.   The recommended range is between 70 and
        90. The default value is 80.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in the export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToAIX(*gp_fixargs((out_aix, resolution, image_quality, compress_vector_graphics, image_compression, jpeg_compression_quality, embed_fonts, embed_color_profile), True)))

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isMapFrameSame(*gp_fixargs((other,), True)))

class MapSurroundElement(_ObjectWithoutInitCall):
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementHeight = passthrough_attr('elementHeight')
    elementWidth = passthrough_attr('elementWidth')
    locked = passthrough_attr('locked')
    name = passthrough_attr('name')
    mapFrame = passthrough_attr('mapFrame')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')

class MapTime(_ObjectWithoutInitCall):
    """The MapTime object is a Map object with time settings."""
    currentTimeStart = passthrough_attr('currentTimeStart')
    currentTimeEnd = passthrough_attr('currentTimeEnd')
    currentTimeSpan = passthrough_attr('currentTimeSpan')
    currentTimeSpanUnits = passthrough_attr('currentTimeSpanUnits')
    timeStepInterval = passthrough_attr('timeStepInterval')
    timeStepIntervalUnits = passthrough_attr('timeStepIntervalUnits')
    isTimeEnabled = passthrough_attr('isTimeEnabled')
    timeInclusion = passthrough_attr('timeInclusion')

    @constants.maskargs
    def timeStep(self, reference_time, interval, interval_units):
        """MapTime.timeStep(reference_time, interval, interval_units)


        The timeStep method returns a new time based on a given reference time
        and a time interval.


        reference_time(DateTime):
        A Python DateTime object. The interval and interval_units will be added
        to the reference_time.The reference_time can be any Python DateTime
        object. For example, you can set the reference_time to be the
        currentStartTime or currentEndTime values.


        interval(Double):
        A double that defines a time interval. Positive or negative intervals
        can be used.


        interval_units(String):
        A string that specifies a valid interval unit.

        * CENTURIES: Centuries

        * SECONDS: Seconds

        * MINUTES: Minutes

        * MONTHS: Months

        * DAYS: Days

        * YEARS: Years

        * HOURS: Hours

        * WEEKS: Weeks

        * DECADES: Decades

        * MILLISECONDS: Milliseconds
        """
        return convertArcObjectToPythonObject(self._arc_object.timeStep(*gp_fixargs((reference_time, interval, interval_units), True)))

    @constants.maskargs
    def setTimeInclusion(self, time_inclusion):
        """MapTime.setTimeInclusion(time_inclusion)


        The setTimeInclusion method controls how  the currentTimeStart and the
        currentTimeEnd are included in the current time span.


        time_inclusion(String):
        A string that specifies a valid time inclusion value.

        * INCLUDE_ONLY_START: Include start time, exclude end time.

        * INCLUDE_ONLY_END: Exclude start time, include end time.

        * INCLUDE_START_AND_END: Include both start and end times.

        * EXCLUDE_START_AND_END: Exclude both start and end times.
        """
        return convertArcObjectToPythonObject(self._arc_object.setTimeInclusion(*gp_fixargs((time_inclusion,), True)))

class PictureElement(_ObjectWithoutInitCall):
    """Provides access to picture properties that enable the repositioning of a
       picture on the page layout as well as getting and setting its data
       source."""
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementRotation = passthrough_attr('elementRotation')
    elementWidth = passthrough_attr('elementWidth')
    locked = passthrough_attr('locked')
    name = passthrough_attr('name')
    sourceImage = passthrough_attr('sourceImage')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
class Table(_ObjectWithoutInitCall):
    """Table(table_data_source)


    Enables you to reference a table in a workspace so that it can be added
    to a Map .


    table_data_source(String):
    A string that includes the full workspace path, including the name of the
    table.  For SDE tables, the workspace path is the path to an SDE
    connection file.
    """
    connectionProperties = passthrough_attr('connectionProperties', True)
    dataSource = passthrough_attr('dataSource', True)
    definitionQuery = passthrough_attr('definitionQuery')
    isBroken = passthrough_attr('isBroken')
    name = passthrough_attr('name')
    longName = passthrough_attr('longName')
    metadata = passthrough_attr('metadata')
    URI = passthrough_attr('URI')

    def getSelectionSet(self):
        """Table.getSelectionSet()


        Returns a table's selection as a Python set of Object IDs.
        """
        return convertArcObjectToPythonObject(self._arc_object.getSelectionSet(*gp_fixargs((), True)))

    @constants.maskargs
    def setSelectionSet(self, oidList=None, method='NEW'):
        """Table.setSelectionSet({oidList}, {method})


        Sets a table's selection using a Python list of Object IDs.


        oidList{List}:
        A Python list of Object IDs to use along with the appropriate selection
        method. The default value is None.


        method{String}:
        A string that specifies which selection method to use. The default value
        is NEW.

        * UNION: Selects all the records in both the current selection and those
        in the oidList.

        * NEW: Creates a new record selection from the oidList.

        * DIFFERENCE: Selects the records that are not in the current selection
        but are in the oidList.

        * SYMDIFFERENCE: Selects the records that are in the current selection
        or the oidList but not both.

        * INTERSECT: Selects the records that are in the current selection and
        the oidList.
        """
        return convertArcObjectToPythonObject(self._arc_object.setSelectionSet(*gp_fixargs((oidList, method), True)))

    def updateConnectionProperties(self, current_connection_info, new_connection_info, auto_update_joins_and_relates=True, validate=True, ignore_case=False):
        """Table.updateConnectionProperties(current_connection_info,
        new_connection_info, {auto_update_joins_and_relates}, {validate},
        {ignore_case})


        The updateConnectionProperties method replaces connection properties
        using a dictionary or a path to a workspace.


        current_connection_info(String):
        A string that represents the workspace path or a Python dictionary that
        contains connection properties to the source you want to update. If an
        empty string or None is used in current_connection_info, all connection
        properties will be replaced with the new_workspace_info, depending on
        the value of the validate parameter.


        new_connection_info(String):
        A string that represents the workspace path or a Python dictionary that
        contains connection properties with the new source information.


        auto_update_joins_and_relates{Boolean}:
        If  set to True, the updateConnectionProperties method will also update
        the connections for associated joins or relates. The default value is
        True.


        validate{Boolean}:
        If  set to True, the connection properties will only be updated if the
        new_connection_info value is a valid connection.  If it is not valid,
        the connection will not be replaced.   If set to False, the method will
        set all connections to match the new_connection_info value, regardless
        of a valid match.  In this case, if a match does not exist, the data
        sources would be broken. The default value is True.


        ignore_case{Boolean}:
        Determines whether searches will be case sensitive. By default, queries
        are case sensitive. To perform queries that are not case sensitive, set
        ignore_case to True. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.updateConnectionProperties(*gp_fixargs((current_connection_info, new_connection_info, auto_update_joins_and_relates, validate, ignore_case), True)))

    def updateDefinitionQueries(self, definitionQueries):
        """Table.updateDefinitionQueries(definitionQueries)


        Updates a table's collection of definition queries.


        definitionQueries(List):
        Updates a list of dictionaries that represent the properties of each
        definition query for a table.
        """
        return convertArcObjectToPythonObject(self._arc_object.updateDefinitionQueries(*gp_fixargs((definitionQueries,), True)))

    def listDefinitionQueries(self, wildcard=None):
        """Table.listDefinitionQueries({wildcard})


        Returns a Python list of definition queries associated with a table.


        wildcard{String}:
        A wildcard is based on the query name and is not case sensitive.  A
        combination of asterisks (*) and characters can be used to limit the
        resulting list. The default value is None.
        """
        return convertArcObjectToPythonObject(self._arc_object.listDefinitionQueries(*gp_fixargs((wildcard,), True)))

    def __init__(self, table_data_source):
        """Table(table_data_source)


        Enables you to reference a table in a workspace so that it can be added to a Map .


        table_data_source(String):
        A string that includes the full workspace path, including the name of the table.
        For SDE tables, the workspace path is the path to an SDE connection file.
        """
        import arcgisscripting
        self._arc_object = arcgisscripting._mapping.Table(*gp_fixargs((table_data_source,), True))

    def __str__(self):
        return self.name

    def __eq__(self, other):
        if type(self)!= type(other):
            return False
        else:
            return convertArcObjectToPythonObject(self._arc_object.isTableSame(*gp_fixargs((other,), True)))

    @constants.maskargs
    def getDefinition(self, cim_version):
        """Table.getDefinition(cim_version)


        Gets a table's CIM definition.


        cim_version(String):
        A string that represents the major version of the CIM.
        """
        from .cim.cimloader import GetJSONTypeOBJ
        import json
        return GetJSONTypeOBJ(json.loads(convertArcObjectToPythonObject(self._arc_object.GetCimJSONString(*gp_fixargs((cim_version), True)))))

    @constants.maskargs
    def setDefinition(self, definition_object):
        """Table.setDefinition(definition_object)


        Sets a table's CIM definition.


        definition_object(Object):
        A modified CIM definition object originally retrieved using
        getDefinition.
        """
        from .cim.cimloader import  CimJsonEncoder
        import json
        json_data = json.dumps(definition_object, cls=CimJsonEncoder)
        return convertArcObjectToPythonObject(self._arc_object.SetCimJSONString(json_data))

    def saveACopy(self, file_name):
        """Table.saveACopy(file_name)


        Saves a table to a layer file (.lyrx).


        file_name(String):
        A string that includes the location and name of the output layer file
        (.lyrx).
        """
        return convertArcObjectToPythonObject(self._arc_object.saveACopy(*gp_fixargs((file_name,), True)))


class TextElement(_ObjectWithoutInitCall):
    """The TextElement object provides access to properties that enable its
       repositioning on the page layout as well as modifying the text string and
       font size."""
    elementHeight = passthrough_attr('elementHeight')
    elementPositionX = passthrough_attr('elementPositionX')
    elementPositionY = passthrough_attr('elementPositionY')
    elementRotation = passthrough_attr('elementRotation')
    elementWidth = passthrough_attr('elementWidth')
    locked = passthrough_attr('locked')
    textAngle = passthrough_attr('textAngle')
    textSize = passthrough_attr('textSize')
    name = passthrough_attr('name')
    text = passthrough_attr('text')
    type = passthrough_attr('type')
    visible = passthrough_attr('visible')
    def clone(self, suffix=None):
        """TextElement.clone({suffix})


        Provides a mechanism to clone an existing  text element on a page
        layout.


        suffix{String}:
        An optional string that is used to tag each newly created text element.
        The new element gets the same element name as the parent text element,
        plus the suffix value, plus a numeric sequencer.  For example, if the
        parent element name is FieldLabel and the suffix value is _copy, the
        newly cloned elements are named  FieldLabel_copy, FieldLabel_copy_1,
        FieldLabel_copy_2, and so on.  If a suffix is not provided, the results
        resemble FieldLabel_1, FieldLabel_2, FieldLabel_3, and so on.
        """
        return convertArcObjectToPythonObject(self._arc_object.clone(*gp_fixargs((suffix,), True)))

    def delete(self):
        """TextElement.delete()


        Provides a mechanism to delete an existing text element on a page
        layout.
        """
        return convertArcObjectToPythonObject(self._arc_object.delete(*gp_fixargs((), True)))

class MapView(_ObjectWithoutInitCall):
    """The MapView."""
    camera = passthrough_attr('camera')
    map = passthrough_attr('map')

    @constants.maskargs
    def exportToAIX(self, out_aix, width, height, resolution=300, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', jpeg_compression_quality=80, embed_fonts=True, embed_color_profile=True):
        """MapView.exportToAIX(out_aix, width, height, {resolution},
        {image_quality}, {compress_vector_graphics}, {image_compression},
        {jpeg_compression_quality}, {embed_fonts}, {embed_color_profile})


        Exports the MapView to Adobe Illustrator Exchange (AIX) format. AIX
        files can be used with the ArcGIS Maps for Adobe Creative Cloud
        extension or Adobe Illustrator.


        out_aix(String):
        A string that represents the path and file name for the output export
        file.


        width(Integer):
        A number that defines the width of the export in pixels.


        height(Integer):
        A number that defines the height of the export in pixels.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 300.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2

        * NORMAL: An output image quality resample ratio of 3

        * FASTEST: An output image quality resample ratio of 5

        * BEST: An output image quality resample ratio of 1

        * FASTER: An output image quality resample ratio of 4


        compress_vector_graphics{Boolean}:
        A Boolean that controls compression of vector and text portions of the
        output file. Image compression is defined separately. The default value
        is True.


        image_compression{String}:
        A string that specifies the compression scheme used to compress image or
        raster data in the output file. The default value is ADAPTIVE.

        * DEFLATE: A lossless data compression.

        * NONE: Compression is not applied.

        * RLE: Run-length encoded compression.

        * JPEG: A lossy data compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.

        * ADAPTIVE: Automatically selects the best compression type for each
        image on the page.   JPEG will be used for large images with many unique
        colors.  DEFLATE will be used for all other images.


        jpeg_compression_quality{Integer}:
        A number that controls compression quality value when image_compression
        is set to ADAPTIVE or JPEG. The valid range is 1 through 100.    A
        jpeg_compression_quality of 100 provides the best quality images but
        creates large export files.   The recommended range is between 70 and
        90. The default value is 80.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in the export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToAIX(*gp_fixargs((out_aix, width, height, resolution, image_quality, compress_vector_graphics, image_compression, jpeg_compression_quality, embed_fonts, embed_color_profile), True)))

    @constants.maskargs
    def exportToBMP(self, out_bmp, width, height, resolution=96, world_file=False,
                    bmp_color_mode='24-BIT_TRUE_COLOR', bmp_image_compression='NONE', embed_color_profile=True):
        """MapView.exportToBMP(out_bmp, width, height, {resolution}, {world_file},
        {bmp_color_mode}, {bmp_image_compression}, {embed_color_profile})


        Exports the MapView to a Microsoft Windows Bitmap (BMP) format file.


        out_bmp(String):
        A string that represents the path and file name of the output export
        file.


        width(Integer):
        A number that defines the width of the export in pixels.


        height(Integer):
        A number that defines the height of the export in pixels.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        world_file{Boolean}:
        If set to True, a georeferenced world file is created. The file contains
        pixel scale information and real-world coordinate information. The
        default value is False.


        bmp_color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 24-BIT_TRUE_COLOR.

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 24-BIT_TRUE_COLOR: 24-bit true color


        bmp_image_compression{String}:
        A string that specifies the compression scheme used to compress image or
        raster data in the output file.  This option only applies to 8-bit
        bmp_color_mode options. The default value is NONE.

        * RLE: Run-length encoded compression.

        * NONE: Compression is not applied.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToBMP(*gp_fixargs((out_bmp, width, height, resolution, world_file, bmp_color_mode, bmp_image_compression, embed_color_profile), True)))

    @constants.maskargs
    def exportToEMF(self, out_emf, width, height, resolution=96, image_quality='BEST', output_as_image=False):
        """MapView.exportToEMF(out_emf, width, height, {resolution},
        {image_quality}, {output_as_image})


        Exports the MapView to an Enhanced Metafile (EMF) format file.


        out_emf(String):
        A string that represents the system path and file name of the output
        export file.


        width(Integer):
        A number that defines the width of the export in pixels.


        height(Integer):
        A number that defines the height of the export in pixels.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2

        * NORMAL: An output image quality resample ratio of 3

        * FASTEST: An output image quality resample ratio of 5

        * BEST: An output image quality resample ratio of 1

        * FASTER: An output image quality resample ratio of 4


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToEMF(*gp_fixargs((out_emf, width, height, resolution, image_quality, output_as_image), True)))

    @constants.maskargs
    def exportToEPS(self, out_eps, width, height, resolution=96, image_compression='DEFLATE', image_quality='BEST',
                   embed_fonts=True, output_as_image=False):
        """MapView.exportToEPS(out_eps, width, height, {resolution},
        {image_compression}, {image_quality}, {embed_fonts}, {output_as_image})


        Exports the MapView to an Encapsulated PostScript (EPS) format file.


        out_eps(String):
        A string that represents the system path and file name of the output
        export file.


        width(Integer):
        A number that defines the width of the export in pixels.


        height(Integer):
        A number that defines the height of the export in pixels.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        image_compression{String}:
        A string that specifies the compression scheme used to compress image or
        raster data in the output file. The default value is DEFLATE.

        * RLE: Run-length encoded compression.

        * NONE: Compression is not applied.

        * DEFLATE: A lossless data compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2.

        * NORMAL: An output image quality resample ratio of 3.

        * FASTEST: An output image quality resample ratio of 5.

        * BEST: An output image quality resample ratio of 1.

        * FASTER: An output image quality resample ratio of 4.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in the export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToEPS(*gp_fixargs((out_eps, width, height, resolution, image_compression, image_quality, embed_fonts, output_as_image), True)))

    @constants.maskargs
    def exportToGIF(self, out_gif, width, height, resolution=96, world_file=False, gif_color_mode='8-BIT_ADAPTIVE_PALETTE'):
        """MapView.exportToGIF(out_gif, width, height, {resolution}, {world_file},
        {gif_color_mode})


        Exports the MapView to a Graphic Interchange Format (GIF) file.


        out_gif(String):
        A string that represents the system path and file name of the output
        export file.


        width(Integer):
        A number that defines the width of the export in pixels.


        height(Integer):
        A number that defines the height of the export in pixels.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        world_file{Boolean}:
        If set to True, a georeferenced world file is created. The file contains
        pixel scale information and real-world coordinate information. The
        default value is False.


        gif_color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 8-BIT_PALETTE.

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 8-BIT_PALETTE: 8-bit adaptive palette
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToGIF(*gp_fixargs((out_gif, width, height, resolution, world_file, gif_color_mode), True)))

    @constants.maskargs
    def exportToJPEG(self, out_jpg, width, height, resolution=96, world_file=False, jpeg_color_mode='24-BIT_TRUE_COLOR', jpeg_quality=80, embed_color_profile=True):
        """MapView.exportToJPEG(out_jpg, width, height, {resolution}, {world_file},
        {jpeg_color_mode}, {jpeg_quality}, {embed_color_profile})


        Exports the MapView to a Joint Photographic Experts Group (JPEG) format
        file.


        out_jpg(String):
        A string that represents the path and file name of the output export
        file.


        width(Integer):
        A number that defines the width of the export in pixels.


        height(Integer):
        A number that defines the height of the export in pixels.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        world_file{Boolean}:
        If set to True, a georeferenced world file is created. The file contains
        pixel scale information and real-world coordinate information.  If you
        export a 3D map frame, this parameter will be ignored regardless of the
        setting, because world files are not applicable to 3D views. The default
        value is False.


        jpeg_color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 24-BIT_TRUE_COLOR.

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 24-BIT_TRUE_COLOR: 24-bit true color


        jpeg_quality{Integer}:
        This value (0–100) controls the amount of compression applied to the
        output image. For JPEG, image quality is adversely affected the more
        compression is applied. A higher quality (highest = 100) setting will
        produce sharper images and larger file sizes. A lower quality setting
        will produce more image artifacts and smaller files. The default value
        is 80.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToJPEG(*gp_fixargs((out_jpg, width, height, resolution, world_file, jpeg_color_mode, jpeg_quality, embed_color_profile), True)))

    @constants.maskargs
    def exportToPDF(self, out_pdf, width, height, resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, layers_attributes='LAYERS_ONLY', georef_info=True, jpeg_compression_quality=80, output_as_image=False, embed_color_profile=True):
        """MapView.exportToPDF(out_pdf, width, height, {resolution},
        {image_quality}, {compress_vector_graphics}, {image_compression},
        {embed_fonts}, {layers_attributes}, {georef_info},
        {jpeg_compression_quality}, {output_as_image}, {embed_color_profile})


        Exports the MapView  to a Portable Document Format (PDF) file.


        out_pdf(String):
        A string that represents the path and file name of the output export
        file.


        width(Integer):
        A number that defines the width of the export in pixels.


        height(Integer):
        A number that defines the height of the export in pixels.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 300.


        image_quality{String}:
        A string that defines the output image quality and the draw resolution
        of map layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2

        * NORMAL: An output image quality resample ratio of 3

        * FASTEST: An output image quality resample ratio of 5

        * BEST: An output image quality resample ratio of 1

        * FASTER: An output image quality resample ratio of 4


        compress_vector_graphics{Boolean}:
        A Boolean that controls the compression of vector and text portions of
        the output file. Image compression is defined separately. The default
        value is True.


        image_compression{String}:
        A string that defines the compression scheme used to compress image or
        raster data in the output file. The default value is ADAPTIVE.

        * DEFLATE: A lossless data compression.

        * NONE: Compression is not applied.

        * RLE: Run-length encoded compression.

        * JPEG: A lossy data compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.

        * ADAPTIVE: Automatically selects the best compression type for each
        image on the page.   JPEG will be used for large images with many unique
        colors.  DEFLATE will be used for all other images.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in the export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        layers_attributes{String}:
        A string that controls the inclusion of PDF layers and PDF object data
        (attributes) in the export file. The default value is LAYERS_ONLY.

        * LAYERS_ONLY: Export PDF layers only.

        * LAYERS_AND_ATTRIBUTES: Export PDF layers and feature attributes.

        * NONE: None.


        georef_info{Boolean}:
        A Boolean that enables the export of coordinate system information for
        each data frame into the output PDF file. The default value is True.


        jpeg_compression_quality{Integer}:
        A number that controls the compression quality value when
        image_compression is set to ADAPTIVE or JPEG. The valid range is 1
        through 100.    A jpeg_compression_quality of 100 provides the best
        quality images but creates large export files.   The recommended range
        is 70 through 90. The default value is 80.


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, width, height, resolution, image_quality, compress_vector_graphics, image_compression, embed_fonts, layers_attributes, georef_info, jpeg_compression_quality, False, output_as_image, embed_color_profile), True)))

    @constants.maskargs
    def exportToPNG(self, out_png, width, height, resolution=96, world_file=False, color_mode='32-BIT_WITH_ALPHA',
                    embed_color_profile=True):
        """MapView.exportToPNG(out_png, width, height, {resolution}, {world_file},
        {color_mode}, {embed_color_profile})


        Exports the MapView to a Portable Network Graphics (PNG) format file.


        out_png(String):
        A string that represents the path and file name of the output export
        file.


        width(Integer):
        A number that defines the width of the export in pixels.


        height(Integer):
        A number that defines the height of the export in pixels.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        world_file{Boolean}:
        If set to True, a georeferenced world file is created. The file contains
        pixel scale information and real-world coordinate information.  If you
        export a 3D map frame, this parameter will be ignored regardless of the
        setting, because world files are not applicable to 3D views. The default
        value is False.


        color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 32-BIT_WITH_ALPHA.

        * 32-BIT_WITH_ALPHA: 32-bit with alpha

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 24-BIT_TRUE_COLOR: 24-bit true color


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToPNG(*gp_fixargs((out_png, width, height, resolution, world_file, color_mode, embed_color_profile), True)))

    @constants.maskargs
    def exportToSVG(self, out_svg, width, height, resolution=96, compress_to_svgz=False, image_quality='BEST', embed_fonts=True, output_as_image=False):
        """MapView.exportToSVG(out_svg, width, height, {resolution},
        {compress_to_svgz}, {image_quality}, {embed_fonts}, {output_as_image})


        Exports the MapView to a Scalable Vector Graphics (SVG) format file.


        out_svg(String):
        A string that represents the path and file name of the output export
        file.


        width(Integer):
        A number that defines the width of the export in pixels.


        height(Integer):
        A number that defines the height of the export in pixels.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        compress_to_svgz{Boolean}:
        If set to True, the output is compressed. The default value is False.


        image_quality{String}:
        A string that specifies output image quality, the draw resolution of map
        layers that draw as rasters. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2.

        * NORMAL: An output image quality resample ratio of 3.

        * FASTEST: An output image quality resample ratio of 5.

        * BEST: An output image quality resample ratio of 1.

        * FASTER: An output image quality resample ratio of 4.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in the export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToSVG(*gp_fixargs((out_svg, width, height, resolution, compress_to_svgz, image_quality, embed_fonts, output_as_image), True)))

    @constants.maskargs
    def exportToTGA(self, out_tga, width, height, resolution=96, world_file=False, color_mode='24-BIT_TRUE_COLOR'):
        """MapView.exportToTGA(out_tga, width, height, {resolution}, {world_file},
        {color_mode})


        Exports the MapView to a Truevision Graphics Adapter (TGA) format file.


        out_tga(String):
        A string that represents the path and file name of the output export
        file.


        width(Integer):
        A number that defines the width of the export in pixels.


        height(Integer):
        A number that defines the height of the export in pixels.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        world_file{Boolean}:
        If set to True, a georeferenced world file is created. The file contains
        pixel scale information and real-world coordinate information. The
        default value is False.


        color_mode{String}:
        This value specifies the number of bits used to describe color. The
        default value is 32-BIT_WITH_ALPHA.

        * 32-BIT_WITH_ALPHA: 32-bit with alpha

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette

        * 8-BIT_GRAYSCALE: 8-bit grayscale

        * 24-BIT_TRUE_COLOR: 24-bit true color
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToTGA(*gp_fixargs((out_tga, width, height, resolution, world_file, color_mode), True)))

    @constants.maskargs
    def exportToTIFF(self, out_tif, width, height, resolution=96, world_file=False, color_mode='24-BIT_TRUE_COLOR', tiff_compression='LZW', geoTIFF_tags=False,
                     jpeg_compression_quality=80, embed_color_profile=True):
        """MapView.exportToTIFF(out_tif, width, height, {resolution}, {world_file},
        {color_mode}, {tiff_compression}, {geoTIFF_tags},
        {jpeg_compression_quality}, {embed_color_profile})


        Exports the MapView to a Tagged Image File Format (TIFF) file.


        out_tif(String):
        A string that represents the path and file name of the output export
        file.


        width(Integer):
        A number that defines the width of the export in pixels.


        height(Integer):
        A number that defines the height of the export in pixels.


        resolution{Integer}:
        A number that defines the resolution of the export file in dots per inch
        (dpi). The default value is 96.


        world_file{Boolean}:
        If set to True, a georeferenced world file is created. The file contains
        pixel scale information and real-world coordinate information.  If you
        export a 3D map frame, this parameter will be ignored regardless of the
        setting, because world files are not applicable to 3D views. The default
        value is False.


        color_mode{String}:
        This value specifies the number of bits used to describe color. The
        available options are dependent on the specified Color Model set in the
        layout's Color Management properties. The default value is
        24-BIT_TRUE_COLOR.

        * 32-BIT_WITH_ALPHA: 32-bit with alpha. Available only to RGB.

        * 8-BIT_ADAPTIVE_PALETTE: 8-bit adaptive palette. Available to RGB and
        CMYK.

        * 40-BIT_CMYK_WITH_ALPHA: 40-bit CMYK with alpha. Available only to
        CMYK.

        * 24-BIT_TRUE_COLOR: 24-bit true color. Available only to RGB.

        * 32-BIT_CMYK_TRUE_COLOR: 32-bit CMYK true color. Available only to
        CMYK.

        * 8-BIT_GRAYSCALE: 8-bit grayscale. Available to RGB and CMYK.


        tiff_compression{String}:
        This value represents a compression scheme. The default value is LZW.

        * DEFLATE: A lossless data compression.

        * NONE: Compression is not applied.

        * JPEG: JPEG compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.

        * PACK_BITS: Pack bits compression.


        geoTIFF_tags{Boolean}:
        If set to True, georeferencing tags are included in the structure of the
        TIFF export file. The tags contain pixel scale information and real-
        world coordinate information. These tags can be read by applications
        that support the GeoTIFF format. The default value is False.


        jpeg_compression_quality{Integer}:
        This value (0–100) controls the amount of compression applied to the
        output image. With a JPEG image, quality is adversely affected the more
        compression is applied. A higher quality (highest = 100) setting will
        produce sharper images and larger file sizes. A lower quality setting
        will produce more image artifacts and smaller files. The default value
        is 80.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToTIFF(*gp_fixargs((out_tif, width, height, resolution, world_file, color_mode, tiff_compression, geoTIFF_tags,
                                              jpeg_compression_quality, embed_color_profile), True)))

    def getLayerExtent(self, layer, selection_only=True, symbolized_extent=True):
        """MapView.getLayerExtent(layer, {selection_only}, {symbolized_extent})


        Returns a layer's extent for all features or only the selected features
        in a layer.


        layer(Layer):
        A reference to a Layer object.


        selection_only{Boolean}:
        If True, it returns the extent for selected features; if False, it
        returns the extent for all features. The default value is True.


        symbolized_extent{Boolean}:
        A value of True will return the layer's symbolized extent; otherwise, it
        will return the geometric extent.  The symbolized extent takes into
        account the area the symbology covers so that it does not get cut off by
        the data frame's boundary. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.getLayerExtent(*gp_fixargs((layer, selection_only, symbolized_extent), True)))

    def panToExtent(self, extent):
        """MapView.panToExtent(extent)


        Pans and centers the MapView using a new Extent object without changing
        the map view's scale.


        extent(Extent):
        A geoprocessing Extent object.
        """
        return convertArcObjectToPythonObject(self._arc_object.panToExtent(*gp_fixargs((extent,), True)))

    def zoomToBookmark(self, bookmark):
        """MapView.zoomToBookmark(bookmark)


        Modifies the MapView view to match the view information stored with a
        spatial bookmark.


        bookmark(Bookmark):
        A reference to a Bookmark object.
        """
        return convertArcObjectToPythonObject(self._arc_object.zoomToBookmark(*gp_fixargs((bookmark,), True)))

    def zoomToAllLayers(self, selection_only=True, symbolized_extent=True):
        """MapView.zoomToAllLayers({selection_only}, {symbolized_extent})


        Modifies the MapView view to match the extent of all layers or selected
        layers in a map.


        selection_only{Boolean}:
        If True, it sets the extent based on the selected  features; if False,
        it sets the extent for all  features in a map. The default value is
        True.


        symbolized_extent{Boolean}:
        A value of True will return the layer's symbolized extent; otherwise, it
        will return the geometric extent.  The symbolized extent takes into
        account the area the symbology covers so that it does not get cut off by
        the map frame's boundary. The default value is True.
        """
        return convertArcObjectToPythonObject(self._arc_object.zoomToAllLayers(*gp_fixargs((selection_only, symbolized_extent), True)))

class MapSeries(_ObjectWithoutInitCall):
    """ MapSeries object provides access to properties."""
    currentPageNumber = passthrough_attr('currentPageNumber')
    mapFrame = passthrough_attr('mapFrame')
    indexLayer = passthrough_attr('indexLayer')
    pageCount = passthrough_attr('pageCount')
    pageNameField = passthrough_attr('pageNameField')
    selectedIndexFeatures = passthrough_attr('selectedIndexFeatures')
    enabled = passthrough_attr('enabled')

    def _convert(self, dictionary):
      from collections import namedtuple
      #replace the special characters ( . ) in spatial fields names with _
      newDict = {key.replace('(', '_').replace(')', '_').replace('.', '_') : value for key, value in dictionary.items()}
      return namedtuple('pageRow', newDict.keys())(**newDict)

    @property
    def pageRow(self):
      return self._convert(convertArcObjectToPythonObject(getattr(self._arc_object, "pageRow")))

    @constants.maskargs
    def exportToPDF(self, out_pdf, page_range_type="ALL", page_range_string="", multiple_files="PDF_SINGLE_FILE", resolution=96, image_quality='BEST', compress_vector_graphics=True, image_compression='ADAPTIVE', embed_fonts=True, layers_attributes='LAYERS_ONLY', georef_info=True, jpeg_compression_quality=80, clip_to_elements=False, show_selection_symbology=False, output_as_image=False, embed_color_profile=True, pdf_accessibility=False, show_export_count=False):
        """MapSeries.exportToPDF(out_pdf, {page_range_type}, {page_range_string},
        {multiple_files}, {resolution}, {image_quality},
        {compress_vector_graphics}, {image_compression}, {embed_fonts},
        {layers_attributes}, {georef_info}, {jpeg_compression_quality},
        {clip_to_elements}, {show_selection_symbology}, {output_as_image},
        {embed_color_profile}, {pdf_accessibility}, {show_export_count})


        Exports a specified set of pages to a Portable Document Format (PDF)
        file for a layout that has map series enabled.


        out_pdf(String):
        A string that represents the path and file name of the output export
        file.


        page_range_type{String}:
        The string value that designates how the pages will be printed. The
        default value is ALL.

        * CURRENT: The active or current page is exported.

        * ALL: All pages are exported.

        * SELECTED: Selected index layer features/pages are exported.

        * RANGE: Only pages listed in the page_range_string parameter are
        exported.


        page_range_string{String}:
        A string that identifies the pages to be exported if the RANGE option in
        the page_range_type parameter is used (for example, 1, 3, 5-12).   If
        any other page_range_type value is used, the page_range_string value
        will be ignored.


        multiple_files{String}:
        A string that controls how the output PDF file is created.  By default,
        all pages are exported into a single, multipage document.  The default
        is PDF_SINGLE_FILE. The default value is PDF_SINGLE_FILE.

        * PDF_SINGLE_FILE: Export  into a multipage, single file document.

        * PDF_MULTIPLE_FILES_PAGE_NUMBER: Export  each map series page to an
        individual file and append the page number to the file name. For
        example, Output.PDF will become Output_1.PDF

        * PDF_MULTIPLE_FILES_PAGE_NAME: Export  each map series page to an
        individual file and append the page name to the file name.  For example,
        Output.PDF will become Output_LakeErie.PDF


        resolution{Integer}:
        An integer that defines the resolution of the export file in dots per
        inch (dpi). The default value is 96.


        image_quality{String}:
        A string that defines output image quality. The default value is BEST.

        * BETTER: An output image quality resample ratio of 2

        * NORMAL: An output image quality resample ratio of 3

        * FASTEST: An output image quality resample ratio of 5

        * BEST: An output image quality resample ratio of 1

        * FASTER: An output image quality resample ratio of 4


        compress_vector_graphics{Boolean}:
        A Boolean that controls the compression of vector and text portions of
        the output file. Image compression is defined separately. The default
        value is True.


        image_compression{String}:
        A string that defines the compression scheme used to compress image or
        raster data in the output file. The default value is ADAPTIVE.

        * NONE: Compression is not applied.

        * RLE: Run-length encoded compression.

        * JPEG: A lossy data compression.

        * LZW: Lempel-Ziv-Welch, a lossless data compression.

        * DEFLATE: A lossless data compression.

        * ADAPTIVE: Automatically selects the best compression type for each
        image on the page.   JPEG will be used for large images with many unique
        colors.  DEFLATE will be used for all other images.


        embed_fonts{Boolean}:
        A Boolean that controls the embedding of fonts in an export file. Font
        embedding allows text and character markers to be displayed correctly
        when the document is viewed on a computer that does not have the
        necessary fonts installed. The default value is True.


        layers_attributes{String}:
        A string that controls the inclusion of PDF layers and PDF object data
        (attributes) in the export file. The default value is LAYERS_ONLY.

        * LAYERS_ONLY: Export PDF layers only.

        * LAYERS_AND_ATTRIBUTES: Export PDF layers and feature attributes.

        * NONE: No setting is applied.


        georef_info{Boolean}:
        A Boolean that enables the export of coordinate system information for
        each map frame into the output PDF file. The default value is True.


        jpeg_compression_quality{Integer}:
        A number that controls the compression quality value when
        image_compression is set to ADAPTIVE or JPEG. The valid range is 1
        through 100.    A jpeg_compression_quality of 100 provides the best
        quality images but creates large export files.   The recommended range
        is 70 through 90. The default value is 80.


        clip_to_elements{Boolean}:
        If set to True, the layout is clipped to the smallest bounding box that
        includes all layout elements. The default value is False.


        show_selection_symbology{Boolean}:
        A Boolean that controls whether the selection symbology should be
        displayed in the output. The default value is False.


        output_as_image{Boolean}:
        If set to True, vector content  can be saved as an image.  Selecting
        this option for maps or layouts that contain vector layers with a high
        density of vertices can reduce the output file size.  When exporting to
        PDF and this option is set to True, you cannot view PDF layers in the
        output. The default value is False.


        embed_color_profile{Boolean}:
        If set to True, color profile information is embedded in the image's
        metadata. The default value is True.


        pdf_accessibility{Boolean}:
        Output a tagged PDF file where text can be read by screen readers or
        other assistive technology.  A tagged PDF file can include alt text—a
        text
        description of a graphic element that a screen reader uses to
        describe the element—for map frames, pictures, and chart frames.
        Alt text is added in the
        Element Pane
         for each element. The default value is False.


        show_export_count{Boolean}:
        If set to True, you will see the status of each page being exported
        displayed in the Python shell. The default value is False.
        """
        return convertArcObjectToPythonObject(self._arc_object.exportToPDF(*gp_fixargs((out_pdf, page_range_type, page_range_string, multiple_files ,resolution, image_quality, compress_vector_graphics, image_compression, embed_fonts, layers_attributes, georef_info, jpeg_compression_quality, clip_to_elements, show_selection_symbology, output_as_image, embed_color_profile, pdf_accessibility, show_export_count), True)))

    def getPageNumberFromName(self, page_name):
        """MapSeries.getPageNumberFromName(page_name)


        Returns a Map Series page number based on the name of the page.


        page_name(String):
        A page number in the index layer that corresponds to the Name field that
        was used to set up the Map Series.
        """
        return convertArcObjectToPythonObject(self._arc_object.getPageNumberFromName(*gp_fixargs((page_name,), True)))

    def refresh(self):
        """MapSeries.refresh()


        Refreshes an existing map series.
        """
        return convertArcObjectToPythonObject(self._arc_object.refresh(*gp_fixargs((), True)))

# Decorate PDFDocument methods with constants lists for Python window
PDFDocument.updateDocProperties.__esri_toolinfo__ = constants.maskargs(PDFDocument.updateDocProperties).__esri_toolinfo__
PDFDocument.updateDocSecurity.__esri_toolinfo__ = constants.maskargs(PDFDocument.updateDocSecurity).__esri_toolinfo__

ob_conversion = (
    ('MappingArcGISProjectObject', ArcGISProject),
    ('MappingBookmarkObject', Bookmark),
    ('MappingCameraObject', Camera),
    ('MappingGraphicElementObject', GraphicElement),
    ('MappingLabelClassObject', LabelClass),
    ('MappingLayerObject', Layer),
    ('MappingLayerFileObject', LayerFile),
    ('MappingLayoutObject', Layout),
    ('MappingLegendElementObject', LegendElement),
    ('MappingReportObject', Report),
    ('MappingReportSectionObject', ReportSection),
    ('MappingReportLayoutSectionObject', ReportLayoutSection),
    ('MappingMapObject', Map),
    ('MappingMapFrameObject', MapFrame),
    ('MappingMapSurroundElementObject', MapSurroundElement),
    ('MappingPictureElementObject', PictureElement),
    ('MappingTableObject', Table),
    ('MappingTextElementObject', TextElement),
    ('MappingMapSeriesObject', MapSeries),
    ('MappingMapViewObject', MapView),
    ('MappingSymbologyObject', Symbology),
    ('MappingColorMapObject', ColorRamp),
    ('MappingSymbolObject', Symbol),
    ('MappingClassBreakObject', ClassBreak),
    ('MappingRasterClassBreakObject', RasterClassBreak),
    ('MappingItemGroupObject', ItemGroup),
    ('MappingItemObject', Item),
    ('MappingRasterItemObject', RasterItem),
    ('MappingLayerTimeObject', LayerTime),
    ('MetadataObject', metadata.Metadata),
    ('MappingMapTimeObject', MapTime),
)
